#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.RiskInfo import RiskInfo


class SubContentRiskInfo(object):

    def __init__(self):
        self._content_file_type = None
        self._ext = None
        self._generated_url = None
        self._ocr_info = None
        self._out_content_id = None
        self._risk_info_list = None

    @property
    def content_file_type(self):
        return self._content_file_type

    @content_file_type.setter
    def content_file_type(self, value):
        self._content_file_type = value
    @property
    def ext(self):
        return self._ext

    @ext.setter
    def ext(self, value):
        self._ext = value
    @property
    def generated_url(self):
        return self._generated_url

    @generated_url.setter
    def generated_url(self, value):
        self._generated_url = value
    @property
    def ocr_info(self):
        return self._ocr_info

    @ocr_info.setter
    def ocr_info(self, value):
        self._ocr_info = value
    @property
    def out_content_id(self):
        return self._out_content_id

    @out_content_id.setter
    def out_content_id(self, value):
        self._out_content_id = value
    @property
    def risk_info_list(self):
        return self._risk_info_list

    @risk_info_list.setter
    def risk_info_list(self, value):
        if isinstance(value, list):
            self._risk_info_list = list()
            for i in value:
                if isinstance(i, RiskInfo):
                    self._risk_info_list.append(i)
                else:
                    self._risk_info_list.append(RiskInfo.from_alipay_dict(i))


    def to_alipay_dict(self):
        params = dict()
        if self.content_file_type:
            if hasattr(self.content_file_type, 'to_alipay_dict'):
                params['content_file_type'] = self.content_file_type.to_alipay_dict()
            else:
                params['content_file_type'] = self.content_file_type
        if self.ext:
            if hasattr(self.ext, 'to_alipay_dict'):
                params['ext'] = self.ext.to_alipay_dict()
            else:
                params['ext'] = self.ext
        if self.generated_url:
            if hasattr(self.generated_url, 'to_alipay_dict'):
                params['generated_url'] = self.generated_url.to_alipay_dict()
            else:
                params['generated_url'] = self.generated_url
        if self.ocr_info:
            if hasattr(self.ocr_info, 'to_alipay_dict'):
                params['ocr_info'] = self.ocr_info.to_alipay_dict()
            else:
                params['ocr_info'] = self.ocr_info
        if self.out_content_id:
            if hasattr(self.out_content_id, 'to_alipay_dict'):
                params['out_content_id'] = self.out_content_id.to_alipay_dict()
            else:
                params['out_content_id'] = self.out_content_id
        if self.risk_info_list:
            if isinstance(self.risk_info_list, list):
                for i in range(0, len(self.risk_info_list)):
                    element = self.risk_info_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.risk_info_list[i] = element.to_alipay_dict()
            if hasattr(self.risk_info_list, 'to_alipay_dict'):
                params['risk_info_list'] = self.risk_info_list.to_alipay_dict()
            else:
                params['risk_info_list'] = self.risk_info_list
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = SubContentRiskInfo()
        if 'content_file_type' in d:
            o.content_file_type = d['content_file_type']
        if 'ext' in d:
            o.ext = d['ext']
        if 'generated_url' in d:
            o.generated_url = d['generated_url']
        if 'ocr_info' in d:
            o.ocr_info = d['ocr_info']
        if 'out_content_id' in d:
            o.out_content_id = d['out_content_id']
        if 'risk_info_list' in d:
            o.risk_info_list = d['risk_info_list']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.ActivitySendVoucherInfo import ActivitySendVoucherInfo


class AlipayMarketingActivityOrdervoucherBatchsendModel(object):

    def __init__(self):
        self._activity_send_voucher_info_list = None
        self._biz_dt = None
        self._open_id = None
        self._promo_trace_info = None
        self._trade_channel = None
        self._trade_no = None
        self._user_id = None

    @property
    def activity_send_voucher_info_list(self):
        return self._activity_send_voucher_info_list

    @activity_send_voucher_info_list.setter
    def activity_send_voucher_info_list(self, value):
        if isinstance(value, list):
            self._activity_send_voucher_info_list = list()
            for i in value:
                if isinstance(i, ActivitySendVoucherInfo):
                    self._activity_send_voucher_info_list.append(i)
                else:
                    self._activity_send_voucher_info_list.append(ActivitySendVoucherInfo.from_alipay_dict(i))
    @property
    def biz_dt(self):
        return self._biz_dt

    @biz_dt.setter
    def biz_dt(self, value):
        self._biz_dt = value
    @property
    def open_id(self):
        return self._open_id

    @open_id.setter
    def open_id(self, value):
        self._open_id = value
    @property
    def promo_trace_info(self):
        return self._promo_trace_info

    @promo_trace_info.setter
    def promo_trace_info(self, value):
        self._promo_trace_info = value
    @property
    def trade_channel(self):
        return self._trade_channel

    @trade_channel.setter
    def trade_channel(self, value):
        self._trade_channel = value
    @property
    def trade_no(self):
        return self._trade_no

    @trade_no.setter
    def trade_no(self, value):
        self._trade_no = value
    @property
    def user_id(self):
        return self._user_id

    @user_id.setter
    def user_id(self, value):
        self._user_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.activity_send_voucher_info_list:
            if isinstance(self.activity_send_voucher_info_list, list):
                for i in range(0, len(self.activity_send_voucher_info_list)):
                    element = self.activity_send_voucher_info_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.activity_send_voucher_info_list[i] = element.to_alipay_dict()
            if hasattr(self.activity_send_voucher_info_list, 'to_alipay_dict'):
                params['activity_send_voucher_info_list'] = self.activity_send_voucher_info_list.to_alipay_dict()
            else:
                params['activity_send_voucher_info_list'] = self.activity_send_voucher_info_list
        if self.biz_dt:
            if hasattr(self.biz_dt, 'to_alipay_dict'):
                params['biz_dt'] = self.biz_dt.to_alipay_dict()
            else:
                params['biz_dt'] = self.biz_dt
        if self.open_id:
            if hasattr(self.open_id, 'to_alipay_dict'):
                params['open_id'] = self.open_id.to_alipay_dict()
            else:
                params['open_id'] = self.open_id
        if self.promo_trace_info:
            if hasattr(self.promo_trace_info, 'to_alipay_dict'):
                params['promo_trace_info'] = self.promo_trace_info.to_alipay_dict()
            else:
                params['promo_trace_info'] = self.promo_trace_info
        if self.trade_channel:
            if hasattr(self.trade_channel, 'to_alipay_dict'):
                params['trade_channel'] = self.trade_channel.to_alipay_dict()
            else:
                params['trade_channel'] = self.trade_channel
        if self.trade_no:
            if hasattr(self.trade_no, 'to_alipay_dict'):
                params['trade_no'] = self.trade_no.to_alipay_dict()
            else:
                params['trade_no'] = self.trade_no
        if self.user_id:
            if hasattr(self.user_id, 'to_alipay_dict'):
                params['user_id'] = self.user_id.to_alipay_dict()
            else:
                params['user_id'] = self.user_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayMarketingActivityOrdervoucherBatchsendModel()
        if 'activity_send_voucher_info_list' in d:
            o.activity_send_voucher_info_list = d['activity_send_voucher_info_list']
        if 'biz_dt' in d:
            o.biz_dt = d['biz_dt']
        if 'open_id' in d:
            o.open_id = d['open_id']
        if 'promo_trace_info' in d:
            o.promo_trace_info = d['promo_trace_info']
        if 'trade_channel' in d:
            o.trade_channel = d['trade_channel']
        if 'trade_no' in d:
            o.trade_no = d['trade_no']
        if 'user_id' in d:
            o.user_id = d['user_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class CommodityPublicExtInfos(object):

    def __init__(self):
        self._action_url = None
        self._app_id = None
        self._category_name = None
        self._city_name = None
        self._commodity_id = None
        self._create_user_id = None
        self._displayapp_id = None
        self._displayapp_memo = None
        self._displayapp_name = None
        self._displayapp_status = None
        self._displayapp_url = None
        self._export_url = None
        self._property_id = None

    @property
    def action_url(self):
        return self._action_url

    @action_url.setter
    def action_url(self, value):
        self._action_url = value
    @property
    def app_id(self):
        return self._app_id

    @app_id.setter
    def app_id(self, value):
        self._app_id = value
    @property
    def category_name(self):
        return self._category_name

    @category_name.setter
    def category_name(self, value):
        self._category_name = value
    @property
    def city_name(self):
        return self._city_name

    @city_name.setter
    def city_name(self, value):
        self._city_name = value
    @property
    def commodity_id(self):
        return self._commodity_id

    @commodity_id.setter
    def commodity_id(self, value):
        self._commodity_id = value
    @property
    def create_user_id(self):
        return self._create_user_id

    @create_user_id.setter
    def create_user_id(self, value):
        self._create_user_id = value
    @property
    def displayapp_id(self):
        return self._displayapp_id

    @displayapp_id.setter
    def displayapp_id(self, value):
        self._displayapp_id = value
    @property
    def displayapp_memo(self):
        return self._displayapp_memo

    @displayapp_memo.setter
    def displayapp_memo(self, value):
        self._displayapp_memo = value
    @property
    def displayapp_name(self):
        return self._displayapp_name

    @displayapp_name.setter
    def displayapp_name(self, value):
        self._displayapp_name = value
    @property
    def displayapp_status(self):
        return self._displayapp_status

    @displayapp_status.setter
    def displayapp_status(self, value):
        self._displayapp_status = value
    @property
    def displayapp_url(self):
        return self._displayapp_url

    @displayapp_url.setter
    def displayapp_url(self, value):
        self._displayapp_url = value
    @property
    def export_url(self):
        return self._export_url

    @export_url.setter
    def export_url(self, value):
        self._export_url = value
    @property
    def property_id(self):
        return self._property_id

    @property_id.setter
    def property_id(self, value):
        self._property_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.action_url:
            if hasattr(self.action_url, 'to_alipay_dict'):
                params['action_url'] = self.action_url.to_alipay_dict()
            else:
                params['action_url'] = self.action_url
        if self.app_id:
            if hasattr(self.app_id, 'to_alipay_dict'):
                params['app_id'] = self.app_id.to_alipay_dict()
            else:
                params['app_id'] = self.app_id
        if self.category_name:
            if hasattr(self.category_name, 'to_alipay_dict'):
                params['category_name'] = self.category_name.to_alipay_dict()
            else:
                params['category_name'] = self.category_name
        if self.city_name:
            if hasattr(self.city_name, 'to_alipay_dict'):
                params['city_name'] = self.city_name.to_alipay_dict()
            else:
                params['city_name'] = self.city_name
        if self.commodity_id:
            if hasattr(self.commodity_id, 'to_alipay_dict'):
                params['commodity_id'] = self.commodity_id.to_alipay_dict()
            else:
                params['commodity_id'] = self.commodity_id
        if self.create_user_id:
            if hasattr(self.create_user_id, 'to_alipay_dict'):
                params['create_user_id'] = self.create_user_id.to_alipay_dict()
            else:
                params['create_user_id'] = self.create_user_id
        if self.displayapp_id:
            if hasattr(self.displayapp_id, 'to_alipay_dict'):
                params['displayapp_id'] = self.displayapp_id.to_alipay_dict()
            else:
                params['displayapp_id'] = self.displayapp_id
        if self.displayapp_memo:
            if hasattr(self.displayapp_memo, 'to_alipay_dict'):
                params['displayapp_memo'] = self.displayapp_memo.to_alipay_dict()
            else:
                params['displayapp_memo'] = self.displayapp_memo
        if self.displayapp_name:
            if hasattr(self.displayapp_name, 'to_alipay_dict'):
                params['displayapp_name'] = self.displayapp_name.to_alipay_dict()
            else:
                params['displayapp_name'] = self.displayapp_name
        if self.displayapp_status:
            if hasattr(self.displayapp_status, 'to_alipay_dict'):
                params['displayapp_status'] = self.displayapp_status.to_alipay_dict()
            else:
                params['displayapp_status'] = self.displayapp_status
        if self.displayapp_url:
            if hasattr(self.displayapp_url, 'to_alipay_dict'):
                params['displayapp_url'] = self.displayapp_url.to_alipay_dict()
            else:
                params['displayapp_url'] = self.displayapp_url
        if self.export_url:
            if hasattr(self.export_url, 'to_alipay_dict'):
                params['export_url'] = self.export_url.to_alipay_dict()
            else:
                params['export_url'] = self.export_url
        if self.property_id:
            if hasattr(self.property_id, 'to_alipay_dict'):
                params['property_id'] = self.property_id.to_alipay_dict()
            else:
                params['property_id'] = self.property_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = CommodityPublicExtInfos()
        if 'action_url' in d:
            o.action_url = d['action_url']
        if 'app_id' in d:
            o.app_id = d['app_id']
        if 'category_name' in d:
            o.category_name = d['category_name']
        if 'city_name' in d:
            o.city_name = d['city_name']
        if 'commodity_id' in d:
            o.commodity_id = d['commodity_id']
        if 'create_user_id' in d:
            o.create_user_id = d['create_user_id']
        if 'displayapp_id' in d:
            o.displayapp_id = d['displayapp_id']
        if 'displayapp_memo' in d:
            o.displayapp_memo = d['displayapp_memo']
        if 'displayapp_name' in d:
            o.displayapp_name = d['displayapp_name']
        if 'displayapp_status' in d:
            o.displayapp_status = d['displayapp_status']
        if 'displayapp_url' in d:
            o.displayapp_url = d['displayapp_url']
        if 'export_url' in d:
            o.export_url = d['export_url']
        if 'property_id' in d:
            o.property_id = d['property_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.AppGroupExt import AppGroupExt
from alipay.aop.api.domain.AppSecurityExt import AppSecurityExt
from alipay.aop.api.domain.EncryptConfigExt import EncryptConfigExt
from alipay.aop.api.domain.ExterfaceExt import ExterfaceExt
from alipay.aop.api.domain.OpenIdConfigRequestExt import OpenIdConfigRequestExt
from alipay.aop.api.domain.QueryAppInfoExt import QueryAppInfoExt
from alipay.aop.api.domain.SecurityProfileExt import SecurityProfileExt


class AlipayOpenOpenbizmocktoolsQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayOpenOpenbizmocktoolsQueryResponse, self).__init__()
        self._app_group_ext = None
        self._app_security_ext = None
        self._encrypt_config_ext = None
        self._exterface_ext = None
        self._open_id_config_request_ext = None
        self._private_key = None
        self._query_app_info_ext = None
        self._security_profile_ext = None
        self._spi_config = None

    @property
    def app_group_ext(self):
        return self._app_group_ext

    @app_group_ext.setter
    def app_group_ext(self, value):
        if isinstance(value, AppGroupExt):
            self._app_group_ext = value
        else:
            self._app_group_ext = AppGroupExt.from_alipay_dict(value)
    @property
    def app_security_ext(self):
        return self._app_security_ext

    @app_security_ext.setter
    def app_security_ext(self, value):
        if isinstance(value, list):
            self._app_security_ext = list()
            for i in value:
                if isinstance(i, AppSecurityExt):
                    self._app_security_ext.append(i)
                else:
                    self._app_security_ext.append(AppSecurityExt.from_alipay_dict(i))
    @property
    def encrypt_config_ext(self):
        return self._encrypt_config_ext

    @encrypt_config_ext.setter
    def encrypt_config_ext(self, value):
        if isinstance(value, list):
            self._encrypt_config_ext = list()
            for i in value:
                if isinstance(i, EncryptConfigExt):
                    self._encrypt_config_ext.append(i)
                else:
                    self._encrypt_config_ext.append(EncryptConfigExt.from_alipay_dict(i))
    @property
    def exterface_ext(self):
        return self._exterface_ext

    @exterface_ext.setter
    def exterface_ext(self, value):
        if isinstance(value, ExterfaceExt):
            self._exterface_ext = value
        else:
            self._exterface_ext = ExterfaceExt.from_alipay_dict(value)
    @property
    def open_id_config_request_ext(self):
        return self._open_id_config_request_ext

    @open_id_config_request_ext.setter
    def open_id_config_request_ext(self, value):
        if isinstance(value, OpenIdConfigRequestExt):
            self._open_id_config_request_ext = value
        else:
            self._open_id_config_request_ext = OpenIdConfigRequestExt.from_alipay_dict(value)
    @property
    def private_key(self):
        return self._private_key

    @private_key.setter
    def private_key(self, value):
        self._private_key = value
    @property
    def query_app_info_ext(self):
        return self._query_app_info_ext

    @query_app_info_ext.setter
    def query_app_info_ext(self, value):
        if isinstance(value, QueryAppInfoExt):
            self._query_app_info_ext = value
        else:
            self._query_app_info_ext = QueryAppInfoExt.from_alipay_dict(value)
    @property
    def security_profile_ext(self):
        return self._security_profile_ext

    @security_profile_ext.setter
    def security_profile_ext(self, value):
        if isinstance(value, list):
            self._security_profile_ext = list()
            for i in value:
                if isinstance(i, SecurityProfileExt):
                    self._security_profile_ext.append(i)
                else:
                    self._security_profile_ext.append(SecurityProfileExt.from_alipay_dict(i))
    @property
    def spi_config(self):
        return self._spi_config

    @spi_config.setter
    def spi_config(self, value):
        self._spi_config = value

    def parse_response_content(self, response_content):
        response = super(AlipayOpenOpenbizmocktoolsQueryResponse, self).parse_response_content(response_content)
        if 'app_group_ext' in response:
            self.app_group_ext = response['app_group_ext']
        if 'app_security_ext' in response:
            self.app_security_ext = response['app_security_ext']
        if 'encrypt_config_ext' in response:
            self.encrypt_config_ext = response['encrypt_config_ext']
        if 'exterface_ext' in response:
            self.exterface_ext = response['exterface_ext']
        if 'open_id_config_request_ext' in response:
            self.open_id_config_request_ext = response['open_id_config_request_ext']
        if 'private_key' in response:
            self.private_key = response['private_key']
        if 'query_app_info_ext' in response:
            self.query_app_info_ext = response['query_app_info_ext']
        if 'security_profile_ext' in response:
            self.security_profile_ext = response['security_profile_ext']
        if 'spi_config' in response:
            self.spi_config = response['spi_config']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class EpLabelContent(object):

    def __init__(self):
        self._label_category = None
        self._label_definition = None
        self._label_emotion = None
        self._label_name = None
        self._label_value = None

    @property
    def label_category(self):
        return self._label_category

    @label_category.setter
    def label_category(self, value):
        self._label_category = value
    @property
    def label_definition(self):
        return self._label_definition

    @label_definition.setter
    def label_definition(self, value):
        self._label_definition = value
    @property
    def label_emotion(self):
        return self._label_emotion

    @label_emotion.setter
    def label_emotion(self, value):
        self._label_emotion = value
    @property
    def label_name(self):
        return self._label_name

    @label_name.setter
    def label_name(self, value):
        self._label_name = value
    @property
    def label_value(self):
        return self._label_value

    @label_value.setter
    def label_value(self, value):
        if isinstance(value, list):
            self._label_value = list()
            for i in value:
                self._label_value.append(i)


    def to_alipay_dict(self):
        params = dict()
        if self.label_category:
            if hasattr(self.label_category, 'to_alipay_dict'):
                params['label_category'] = self.label_category.to_alipay_dict()
            else:
                params['label_category'] = self.label_category
        if self.label_definition:
            if hasattr(self.label_definition, 'to_alipay_dict'):
                params['label_definition'] = self.label_definition.to_alipay_dict()
            else:
                params['label_definition'] = self.label_definition
        if self.label_emotion:
            if hasattr(self.label_emotion, 'to_alipay_dict'):
                params['label_emotion'] = self.label_emotion.to_alipay_dict()
            else:
                params['label_emotion'] = self.label_emotion
        if self.label_name:
            if hasattr(self.label_name, 'to_alipay_dict'):
                params['label_name'] = self.label_name.to_alipay_dict()
            else:
                params['label_name'] = self.label_name
        if self.label_value:
            if isinstance(self.label_value, list):
                for i in range(0, len(self.label_value)):
                    element = self.label_value[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.label_value[i] = element.to_alipay_dict()
            if hasattr(self.label_value, 'to_alipay_dict'):
                params['label_value'] = self.label_value.to_alipay_dict()
            else:
                params['label_value'] = self.label_value
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = EpLabelContent()
        if 'label_category' in d:
            o.label_category = d['label_category']
        if 'label_definition' in d:
            o.label_definition = d['label_definition']
        if 'label_emotion' in d:
            o.label_emotion = d['label_emotion']
        if 'label_name' in d:
            o.label_name = d['label_name']
        if 'label_value' in d:
            o.label_value = d['label_value']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayFundTransAuctionBalanceQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayFundTransAuctionBalanceQueryResponse, self).__init__()
        self._balance_available = None
        self._balance_freezed = None

    @property
    def balance_available(self):
        return self._balance_available

    @balance_available.setter
    def balance_available(self, value):
        self._balance_available = value
    @property
    def balance_freezed(self):
        return self._balance_freezed

    @balance_freezed.setter
    def balance_freezed(self, value):
        self._balance_freezed = value

    def parse_response_content(self, response_content):
        response = super(AlipayFundTransAuctionBalanceQueryResponse, self).parse_response_content(response_content)
        if 'balance_available' in response:
            self.balance_available = response['balance_available']
        if 'balance_freezed' in response:
            self.balance_freezed = response['balance_freezed']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class SettleDetailInfoDTO(object):

    def __init__(self):
        self._actual_amount = None
        self._amount = None
        self._settle_entity_id = None
        self._settle_entity_type = None
        self._summary_dimension = None
        self._trans_in = None
        self._trans_in_type = None

    @property
    def actual_amount(self):
        return self._actual_amount

    @actual_amount.setter
    def actual_amount(self, value):
        self._actual_amount = value
    @property
    def amount(self):
        return self._amount

    @amount.setter
    def amount(self, value):
        self._amount = value
    @property
    def settle_entity_id(self):
        return self._settle_entity_id

    @settle_entity_id.setter
    def settle_entity_id(self, value):
        self._settle_entity_id = value
    @property
    def settle_entity_type(self):
        return self._settle_entity_type

    @settle_entity_type.setter
    def settle_entity_type(self, value):
        self._settle_entity_type = value
    @property
    def summary_dimension(self):
        return self._summary_dimension

    @summary_dimension.setter
    def summary_dimension(self, value):
        self._summary_dimension = value
    @property
    def trans_in(self):
        return self._trans_in

    @trans_in.setter
    def trans_in(self, value):
        self._trans_in = value
    @property
    def trans_in_type(self):
        return self._trans_in_type

    @trans_in_type.setter
    def trans_in_type(self, value):
        self._trans_in_type = value


    def to_alipay_dict(self):
        params = dict()
        if self.actual_amount:
            if hasattr(self.actual_amount, 'to_alipay_dict'):
                params['actual_amount'] = self.actual_amount.to_alipay_dict()
            else:
                params['actual_amount'] = self.actual_amount
        if self.amount:
            if hasattr(self.amount, 'to_alipay_dict'):
                params['amount'] = self.amount.to_alipay_dict()
            else:
                params['amount'] = self.amount
        if self.settle_entity_id:
            if hasattr(self.settle_entity_id, 'to_alipay_dict'):
                params['settle_entity_id'] = self.settle_entity_id.to_alipay_dict()
            else:
                params['settle_entity_id'] = self.settle_entity_id
        if self.settle_entity_type:
            if hasattr(self.settle_entity_type, 'to_alipay_dict'):
                params['settle_entity_type'] = self.settle_entity_type.to_alipay_dict()
            else:
                params['settle_entity_type'] = self.settle_entity_type
        if self.summary_dimension:
            if hasattr(self.summary_dimension, 'to_alipay_dict'):
                params['summary_dimension'] = self.summary_dimension.to_alipay_dict()
            else:
                params['summary_dimension'] = self.summary_dimension
        if self.trans_in:
            if hasattr(self.trans_in, 'to_alipay_dict'):
                params['trans_in'] = self.trans_in.to_alipay_dict()
            else:
                params['trans_in'] = self.trans_in
        if self.trans_in_type:
            if hasattr(self.trans_in_type, 'to_alipay_dict'):
                params['trans_in_type'] = self.trans_in_type.to_alipay_dict()
            else:
                params['trans_in_type'] = self.trans_in_type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = SettleDetailInfoDTO()
        if 'actual_amount' in d:
            o.actual_amount = d['actual_amount']
        if 'amount' in d:
            o.amount = d['amount']
        if 'settle_entity_id' in d:
            o.settle_entity_id = d['settle_entity_id']
        if 'settle_entity_type' in d:
            o.settle_entity_type = d['settle_entity_type']
        if 'summary_dimension' in d:
            o.summary_dimension = d['summary_dimension']
        if 'trans_in' in d:
            o.trans_in = d['trans_in']
        if 'trans_in_type' in d:
            o.trans_in_type = d['trans_in_type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.RpaCrawlerQueryCriteriaVO import RpaCrawlerQueryCriteriaVO


class AlipayPcreditHuabeiRpacrawlerQueryModel(object):

    def __init__(self):
        self._biz_type = None
        self._function_type = None
        self._offset = None
        self._out_biz_no = None
        self._page_size = None
        self._query_criteria = None
        self._sync_task_status = None
        self._task_id = None

    @property
    def biz_type(self):
        return self._biz_type

    @biz_type.setter
    def biz_type(self, value):
        self._biz_type = value
    @property
    def function_type(self):
        return self._function_type

    @function_type.setter
    def function_type(self, value):
        self._function_type = value
    @property
    def offset(self):
        return self._offset

    @offset.setter
    def offset(self, value):
        self._offset = value
    @property
    def out_biz_no(self):
        return self._out_biz_no

    @out_biz_no.setter
    def out_biz_no(self, value):
        self._out_biz_no = value
    @property
    def page_size(self):
        return self._page_size

    @page_size.setter
    def page_size(self, value):
        self._page_size = value
    @property
    def query_criteria(self):
        return self._query_criteria

    @query_criteria.setter
    def query_criteria(self, value):
        if isinstance(value, list):
            self._query_criteria = list()
            for i in value:
                if isinstance(i, RpaCrawlerQueryCriteriaVO):
                    self._query_criteria.append(i)
                else:
                    self._query_criteria.append(RpaCrawlerQueryCriteriaVO.from_alipay_dict(i))
    @property
    def sync_task_status(self):
        return self._sync_task_status

    @sync_task_status.setter
    def sync_task_status(self, value):
        self._sync_task_status = value
    @property
    def task_id(self):
        return self._task_id

    @task_id.setter
    def task_id(self, value):
        self._task_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.biz_type:
            if hasattr(self.biz_type, 'to_alipay_dict'):
                params['biz_type'] = self.biz_type.to_alipay_dict()
            else:
                params['biz_type'] = self.biz_type
        if self.function_type:
            if hasattr(self.function_type, 'to_alipay_dict'):
                params['function_type'] = self.function_type.to_alipay_dict()
            else:
                params['function_type'] = self.function_type
        if self.offset:
            if hasattr(self.offset, 'to_alipay_dict'):
                params['offset'] = self.offset.to_alipay_dict()
            else:
                params['offset'] = self.offset
        if self.out_biz_no:
            if hasattr(self.out_biz_no, 'to_alipay_dict'):
                params['out_biz_no'] = self.out_biz_no.to_alipay_dict()
            else:
                params['out_biz_no'] = self.out_biz_no
        if self.page_size:
            if hasattr(self.page_size, 'to_alipay_dict'):
                params['page_size'] = self.page_size.to_alipay_dict()
            else:
                params['page_size'] = self.page_size
        if self.query_criteria:
            if isinstance(self.query_criteria, list):
                for i in range(0, len(self.query_criteria)):
                    element = self.query_criteria[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.query_criteria[i] = element.to_alipay_dict()
            if hasattr(self.query_criteria, 'to_alipay_dict'):
                params['query_criteria'] = self.query_criteria.to_alipay_dict()
            else:
                params['query_criteria'] = self.query_criteria
        if self.sync_task_status:
            if hasattr(self.sync_task_status, 'to_alipay_dict'):
                params['sync_task_status'] = self.sync_task_status.to_alipay_dict()
            else:
                params['sync_task_status'] = self.sync_task_status
        if self.task_id:
            if hasattr(self.task_id, 'to_alipay_dict'):
                params['task_id'] = self.task_id.to_alipay_dict()
            else:
                params['task_id'] = self.task_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayPcreditHuabeiRpacrawlerQueryModel()
        if 'biz_type' in d:
            o.biz_type = d['biz_type']
        if 'function_type' in d:
            o.function_type = d['function_type']
        if 'offset' in d:
            o.offset = d['offset']
        if 'out_biz_no' in d:
            o.out_biz_no = d['out_biz_no']
        if 'page_size' in d:
            o.page_size = d['page_size']
        if 'query_criteria' in d:
            o.query_criteria = d['query_criteria']
        if 'sync_task_status' in d:
            o.sync_task_status = d['sync_task_status']
        if 'task_id' in d:
            o.task_id = d['task_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.SupplierAssetResponse import SupplierAssetResponse


class AlipayCommerceIotSupplierAssetModifyModel(object):

    def __init__(self):
        self._record = None

    @property
    def record(self):
        return self._record

    @record.setter
    def record(self, value):
        if isinstance(value, SupplierAssetResponse):
            self._record = value
        else:
            self._record = SupplierAssetResponse.from_alipay_dict(value)


    def to_alipay_dict(self):
        params = dict()
        if self.record:
            if hasattr(self.record, 'to_alipay_dict'):
                params['record'] = self.record.to_alipay_dict()
            else:
                params['record'] = self.record
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayCommerceIotSupplierAssetModifyModel()
        if 'record' in d:
            o.record = d['record']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.ApSummaryBillViewQueryOrder import ApSummaryBillViewQueryOrder


class AlipayBossFncGfsettleprodSumapsummarybillQueryModel(object):

    def __init__(self):
        self._ap_summary_bill_view_query_orde = None

    @property
    def ap_summary_bill_view_query_orde(self):
        return self._ap_summary_bill_view_query_orde

    @ap_summary_bill_view_query_orde.setter
    def ap_summary_bill_view_query_orde(self, value):
        if isinstance(value, ApSummaryBillViewQueryOrder):
            self._ap_summary_bill_view_query_orde = value
        else:
            self._ap_summary_bill_view_query_orde = ApSummaryBillViewQueryOrder.from_alipay_dict(value)


    def to_alipay_dict(self):
        params = dict()
        if self.ap_summary_bill_view_query_orde:
            if hasattr(self.ap_summary_bill_view_query_orde, 'to_alipay_dict'):
                params['ap_summary_bill_view_query_orde'] = self.ap_summary_bill_view_query_orde.to_alipay_dict()
            else:
                params['ap_summary_bill_view_query_orde'] = self.ap_summary_bill_view_query_orde
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayBossFncGfsettleprodSumapsummarybillQueryModel()
        if 'ap_summary_bill_view_query_orde' in d:
            o.ap_summary_bill_view_query_orde = d['ap_summary_bill_view_query_orde']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class UserConfirmPayload(object):

    def __init__(self):
        self._scene = None
        self._user_token = None

    @property
    def scene(self):
        return self._scene

    @scene.setter
    def scene(self, value):
        self._scene = value
    @property
    def user_token(self):
        return self._user_token

    @user_token.setter
    def user_token(self, value):
        self._user_token = value


    def to_alipay_dict(self):
        params = dict()
        if self.scene:
            if hasattr(self.scene, 'to_alipay_dict'):
                params['scene'] = self.scene.to_alipay_dict()
            else:
                params['scene'] = self.scene
        if self.user_token:
            if hasattr(self.user_token, 'to_alipay_dict'):
                params['user_token'] = self.user_token.to_alipay_dict()
            else:
                params['user_token'] = self.user_token
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = UserConfirmPayload()
        if 'scene' in d:
            o.scene = d['scene']
        if 'user_token' in d:
            o.user_token = d['user_token']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class CreditRateResult(object):

    def __init__(self):
        self._cr_rank = None
        self._cr_rank_title = None
        self._ep_cert_no = None
        self._ep_name = None
        self._ep_status = None
        self._pass_status = None

    @property
    def cr_rank(self):
        return self._cr_rank

    @cr_rank.setter
    def cr_rank(self, value):
        self._cr_rank = value
    @property
    def cr_rank_title(self):
        return self._cr_rank_title

    @cr_rank_title.setter
    def cr_rank_title(self, value):
        self._cr_rank_title = value
    @property
    def ep_cert_no(self):
        return self._ep_cert_no

    @ep_cert_no.setter
    def ep_cert_no(self, value):
        self._ep_cert_no = value
    @property
    def ep_name(self):
        return self._ep_name

    @ep_name.setter
    def ep_name(self, value):
        self._ep_name = value
    @property
    def ep_status(self):
        return self._ep_status

    @ep_status.setter
    def ep_status(self, value):
        self._ep_status = value
    @property
    def pass_status(self):
        return self._pass_status

    @pass_status.setter
    def pass_status(self, value):
        self._pass_status = value


    def to_alipay_dict(self):
        params = dict()
        if self.cr_rank:
            if hasattr(self.cr_rank, 'to_alipay_dict'):
                params['cr_rank'] = self.cr_rank.to_alipay_dict()
            else:
                params['cr_rank'] = self.cr_rank
        if self.cr_rank_title:
            if hasattr(self.cr_rank_title, 'to_alipay_dict'):
                params['cr_rank_title'] = self.cr_rank_title.to_alipay_dict()
            else:
                params['cr_rank_title'] = self.cr_rank_title
        if self.ep_cert_no:
            if hasattr(self.ep_cert_no, 'to_alipay_dict'):
                params['ep_cert_no'] = self.ep_cert_no.to_alipay_dict()
            else:
                params['ep_cert_no'] = self.ep_cert_no
        if self.ep_name:
            if hasattr(self.ep_name, 'to_alipay_dict'):
                params['ep_name'] = self.ep_name.to_alipay_dict()
            else:
                params['ep_name'] = self.ep_name
        if self.ep_status:
            if hasattr(self.ep_status, 'to_alipay_dict'):
                params['ep_status'] = self.ep_status.to_alipay_dict()
            else:
                params['ep_status'] = self.ep_status
        if self.pass_status:
            if hasattr(self.pass_status, 'to_alipay_dict'):
                params['pass_status'] = self.pass_status.to_alipay_dict()
            else:
                params['pass_status'] = self.pass_status
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = CreditRateResult()
        if 'cr_rank' in d:
            o.cr_rank = d['cr_rank']
        if 'cr_rank_title' in d:
            o.cr_rank_title = d['cr_rank_title']
        if 'ep_cert_no' in d:
            o.ep_cert_no = d['ep_cert_no']
        if 'ep_name' in d:
            o.ep_name = d['ep_name']
        if 'ep_status' in d:
            o.ep_status = d['ep_status']
        if 'pass_status' in d:
            o.pass_status = d['pass_status']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayEbppEbppPdeductCzsignUpgradeResponse(AlipayResponse):

    def __init__(self):
        super(AlipayEbppEbppPdeductCzsignUpgradeResponse, self).__init__()
        self._error_message = None
        self._new_agreement_id = None
        self._open_id = None
        self._success = None
        self._user_id = None

    @property
    def error_message(self):
        return self._error_message

    @error_message.setter
    def error_message(self, value):
        self._error_message = value
    @property
    def new_agreement_id(self):
        return self._new_agreement_id

    @new_agreement_id.setter
    def new_agreement_id(self, value):
        self._new_agreement_id = value
    @property
    def open_id(self):
        return self._open_id

    @open_id.setter
    def open_id(self, value):
        self._open_id = value
    @property
    def success(self):
        return self._success

    @success.setter
    def success(self, value):
        self._success = value
    @property
    def user_id(self):
        return self._user_id

    @user_id.setter
    def user_id(self, value):
        self._user_id = value

    def parse_response_content(self, response_content):
        response = super(AlipayEbppEbppPdeductCzsignUpgradeResponse, self).parse_response_content(response_content)
        if 'error_message' in response:
            self.error_message = response['error_message']
        if 'new_agreement_id' in response:
            self.new_agreement_id = response['new_agreement_id']
        if 'open_id' in response:
            self.open_id = response['open_id']
        if 'success' in response:
            self.success = response['success']
        if 'user_id' in response:
            self.user_id = response['user_id']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.BenefitDetailInfo import BenefitDetailInfo


class AlipayOverseasTravelBenefitChangeNotifyModel(object):

    def __init__(self):
        self._acquirer_id = None
        self._benefit_detail_info_list = None
        self._psp_id = None

    @property
    def acquirer_id(self):
        return self._acquirer_id

    @acquirer_id.setter
    def acquirer_id(self, value):
        self._acquirer_id = value
    @property
    def benefit_detail_info_list(self):
        return self._benefit_detail_info_list

    @benefit_detail_info_list.setter
    def benefit_detail_info_list(self, value):
        if isinstance(value, list):
            self._benefit_detail_info_list = list()
            for i in value:
                if isinstance(i, BenefitDetailInfo):
                    self._benefit_detail_info_list.append(i)
                else:
                    self._benefit_detail_info_list.append(BenefitDetailInfo.from_alipay_dict(i))
    @property
    def psp_id(self):
        return self._psp_id

    @psp_id.setter
    def psp_id(self, value):
        self._psp_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.acquirer_id:
            if hasattr(self.acquirer_id, 'to_alipay_dict'):
                params['acquirer_id'] = self.acquirer_id.to_alipay_dict()
            else:
                params['acquirer_id'] = self.acquirer_id
        if self.benefit_detail_info_list:
            if isinstance(self.benefit_detail_info_list, list):
                for i in range(0, len(self.benefit_detail_info_list)):
                    element = self.benefit_detail_info_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.benefit_detail_info_list[i] = element.to_alipay_dict()
            if hasattr(self.benefit_detail_info_list, 'to_alipay_dict'):
                params['benefit_detail_info_list'] = self.benefit_detail_info_list.to_alipay_dict()
            else:
                params['benefit_detail_info_list'] = self.benefit_detail_info_list
        if self.psp_id:
            if hasattr(self.psp_id, 'to_alipay_dict'):
                params['psp_id'] = self.psp_id.to_alipay_dict()
            else:
                params['psp_id'] = self.psp_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayOverseasTravelBenefitChangeNotifyModel()
        if 'acquirer_id' in d:
            o.acquirer_id = d['acquirer_id']
        if 'benefit_detail_info_list' in d:
            o.benefit_detail_info_list = d['benefit_detail_info_list']
        if 'psp_id' in d:
            o.psp_id = d['psp_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.CfbudmacBizActionLogDTO import CfbudmacBizActionLogDTO


class MyxiaojinFinanceBudgetApplyResponse(AlipayResponse):

    def __init__(self):
        super(MyxiaojinFinanceBudgetApplyResponse, self).__init__()
        self._result_data = None
        self._result_msg = None

    @property
    def result_data(self):
        return self._result_data

    @result_data.setter
    def result_data(self, value):
        if isinstance(value, list):
            self._result_data = list()
            for i in value:
                if isinstance(i, CfbudmacBizActionLogDTO):
                    self._result_data.append(i)
                else:
                    self._result_data.append(CfbudmacBizActionLogDTO.from_alipay_dict(i))
    @property
    def result_msg(self):
        return self._result_msg

    @result_msg.setter
    def result_msg(self, value):
        self._result_msg = value

    def parse_response_content(self, response_content):
        response = super(MyxiaojinFinanceBudgetApplyResponse, self).parse_response_content(response_content)
        if 'result_data' in response:
            self.result_data = response['result_data']
        if 'result_msg' in response:
            self.result_msg = response['result_msg']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class BaseCrossborderMerchantInfo(object):

    def __init__(self):
        self._ext_info = None
        self._org_name = None
        self._uscc = None

    @property
    def ext_info(self):
        return self._ext_info

    @ext_info.setter
    def ext_info(self, value):
        self._ext_info = value
    @property
    def org_name(self):
        return self._org_name

    @org_name.setter
    def org_name(self, value):
        self._org_name = value
    @property
    def uscc(self):
        return self._uscc

    @uscc.setter
    def uscc(self, value):
        self._uscc = value


    def to_alipay_dict(self):
        params = dict()
        if self.ext_info:
            if hasattr(self.ext_info, 'to_alipay_dict'):
                params['ext_info'] = self.ext_info.to_alipay_dict()
            else:
                params['ext_info'] = self.ext_info
        if self.org_name:
            if hasattr(self.org_name, 'to_alipay_dict'):
                params['org_name'] = self.org_name.to_alipay_dict()
            else:
                params['org_name'] = self.org_name
        if self.uscc:
            if hasattr(self.uscc, 'to_alipay_dict'):
                params['uscc'] = self.uscc.to_alipay_dict()
            else:
                params['uscc'] = self.uscc
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = BaseCrossborderMerchantInfo()
        if 'ext_info' in d:
            o.ext_info = d['ext_info']
        if 'org_name' in d:
            o.org_name = d['org_name']
        if 'uscc' in d:
            o.uscc = d['uscc']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.DetectServiceEntity import DetectServiceEntity


class AlipayEbppDetectCreateModel(object):

    def __init__(self):
        self._biz_type = None
        self._data_from_type = None
        self._out_biz_no = None
        self._service_list = None
        self._tinyapp_id = None
        self._tinyapp_partner_id = None

    @property
    def biz_type(self):
        return self._biz_type

    @biz_type.setter
    def biz_type(self, value):
        self._biz_type = value
    @property
    def data_from_type(self):
        return self._data_from_type

    @data_from_type.setter
    def data_from_type(self, value):
        self._data_from_type = value
    @property
    def out_biz_no(self):
        return self._out_biz_no

    @out_biz_no.setter
    def out_biz_no(self, value):
        self._out_biz_no = value
    @property
    def service_list(self):
        return self._service_list

    @service_list.setter
    def service_list(self, value):
        if isinstance(value, list):
            self._service_list = list()
            for i in value:
                if isinstance(i, DetectServiceEntity):
                    self._service_list.append(i)
                else:
                    self._service_list.append(DetectServiceEntity.from_alipay_dict(i))
    @property
    def tinyapp_id(self):
        return self._tinyapp_id

    @tinyapp_id.setter
    def tinyapp_id(self, value):
        self._tinyapp_id = value
    @property
    def tinyapp_partner_id(self):
        return self._tinyapp_partner_id

    @tinyapp_partner_id.setter
    def tinyapp_partner_id(self, value):
        self._tinyapp_partner_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.biz_type:
            if hasattr(self.biz_type, 'to_alipay_dict'):
                params['biz_type'] = self.biz_type.to_alipay_dict()
            else:
                params['biz_type'] = self.biz_type
        if self.data_from_type:
            if hasattr(self.data_from_type, 'to_alipay_dict'):
                params['data_from_type'] = self.data_from_type.to_alipay_dict()
            else:
                params['data_from_type'] = self.data_from_type
        if self.out_biz_no:
            if hasattr(self.out_biz_no, 'to_alipay_dict'):
                params['out_biz_no'] = self.out_biz_no.to_alipay_dict()
            else:
                params['out_biz_no'] = self.out_biz_no
        if self.service_list:
            if isinstance(self.service_list, list):
                for i in range(0, len(self.service_list)):
                    element = self.service_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.service_list[i] = element.to_alipay_dict()
            if hasattr(self.service_list, 'to_alipay_dict'):
                params['service_list'] = self.service_list.to_alipay_dict()
            else:
                params['service_list'] = self.service_list
        if self.tinyapp_id:
            if hasattr(self.tinyapp_id, 'to_alipay_dict'):
                params['tinyapp_id'] = self.tinyapp_id.to_alipay_dict()
            else:
                params['tinyapp_id'] = self.tinyapp_id
        if self.tinyapp_partner_id:
            if hasattr(self.tinyapp_partner_id, 'to_alipay_dict'):
                params['tinyapp_partner_id'] = self.tinyapp_partner_id.to_alipay_dict()
            else:
                params['tinyapp_partner_id'] = self.tinyapp_partner_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayEbppDetectCreateModel()
        if 'biz_type' in d:
            o.biz_type = d['biz_type']
        if 'data_from_type' in d:
            o.data_from_type = d['data_from_type']
        if 'out_biz_no' in d:
            o.out_biz_no = d['out_biz_no']
        if 'service_list' in d:
            o.service_list = d['service_list']
        if 'tinyapp_id' in d:
            o.tinyapp_id = d['tinyapp_id']
        if 'tinyapp_partner_id' in d:
            o.tinyapp_partner_id = d['tinyapp_partner_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class MybankEcnyTradeCancelModel(object):

    def __init__(self):
        self._merchant_id = None
        self._out_trade_no = None
        self._trade_no = None

    @property
    def merchant_id(self):
        return self._merchant_id

    @merchant_id.setter
    def merchant_id(self, value):
        self._merchant_id = value
    @property
    def out_trade_no(self):
        return self._out_trade_no

    @out_trade_no.setter
    def out_trade_no(self, value):
        self._out_trade_no = value
    @property
    def trade_no(self):
        return self._trade_no

    @trade_no.setter
    def trade_no(self, value):
        self._trade_no = value


    def to_alipay_dict(self):
        params = dict()
        if self.merchant_id:
            if hasattr(self.merchant_id, 'to_alipay_dict'):
                params['merchant_id'] = self.merchant_id.to_alipay_dict()
            else:
                params['merchant_id'] = self.merchant_id
        if self.out_trade_no:
            if hasattr(self.out_trade_no, 'to_alipay_dict'):
                params['out_trade_no'] = self.out_trade_no.to_alipay_dict()
            else:
                params['out_trade_no'] = self.out_trade_no
        if self.trade_no:
            if hasattr(self.trade_no, 'to_alipay_dict'):
                params['trade_no'] = self.trade_no.to_alipay_dict()
            else:
                params['trade_no'] = self.trade_no
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = MybankEcnyTradeCancelModel()
        if 'merchant_id' in d:
            o.merchant_id = d['merchant_id']
        if 'out_trade_no' in d:
            o.out_trade_no = d['out_trade_no']
        if 'trade_no' in d:
            o.trade_no = d['trade_no']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AntfortuneQuotationResearchdataQueryResponse(AlipayResponse):

    def __init__(self):
        super(AntfortuneQuotationResearchdataQueryResponse, self).__init__()
        self._result_code = None
        self._result_content = None
        self._result_desc = None
        self._result_success = None

    @property
    def result_code(self):
        return self._result_code

    @result_code.setter
    def result_code(self, value):
        self._result_code = value
    @property
    def result_content(self):
        return self._result_content

    @result_content.setter
    def result_content(self, value):
        self._result_content = value
    @property
    def result_desc(self):
        return self._result_desc

    @result_desc.setter
    def result_desc(self, value):
        self._result_desc = value
    @property
    def result_success(self):
        return self._result_success

    @result_success.setter
    def result_success(self, value):
        self._result_success = value

    def parse_response_content(self, response_content):
        response = super(AntfortuneQuotationResearchdataQueryResponse, self).parse_response_content(response_content)
        if 'result_code' in response:
            self.result_code = response['result_code']
        if 'result_content' in response:
            self.result_content = response['result_content']
        if 'result_desc' in response:
            self.result_desc = response['result_desc']
        if 'result_success' in response:
            self.result_success = response['result_success']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayCommerceTransportEtcBindModifyModel(object):

    def __init__(self):
        self._bind_agreement_no = None
        self._binded_mobile = None
        self._card_no = None
        self._device_no = None

    @property
    def bind_agreement_no(self):
        return self._bind_agreement_no

    @bind_agreement_no.setter
    def bind_agreement_no(self, value):
        self._bind_agreement_no = value
    @property
    def binded_mobile(self):
        return self._binded_mobile

    @binded_mobile.setter
    def binded_mobile(self, value):
        self._binded_mobile = value
    @property
    def card_no(self):
        return self._card_no

    @card_no.setter
    def card_no(self, value):
        self._card_no = value
    @property
    def device_no(self):
        return self._device_no

    @device_no.setter
    def device_no(self, value):
        self._device_no = value


    def to_alipay_dict(self):
        params = dict()
        if self.bind_agreement_no:
            if hasattr(self.bind_agreement_no, 'to_alipay_dict'):
                params['bind_agreement_no'] = self.bind_agreement_no.to_alipay_dict()
            else:
                params['bind_agreement_no'] = self.bind_agreement_no
        if self.binded_mobile:
            if hasattr(self.binded_mobile, 'to_alipay_dict'):
                params['binded_mobile'] = self.binded_mobile.to_alipay_dict()
            else:
                params['binded_mobile'] = self.binded_mobile
        if self.card_no:
            if hasattr(self.card_no, 'to_alipay_dict'):
                params['card_no'] = self.card_no.to_alipay_dict()
            else:
                params['card_no'] = self.card_no
        if self.device_no:
            if hasattr(self.device_no, 'to_alipay_dict'):
                params['device_no'] = self.device_no.to_alipay_dict()
            else:
                params['device_no'] = self.device_no
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayCommerceTransportEtcBindModifyModel()
        if 'bind_agreement_no' in d:
            o.bind_agreement_no = d['bind_agreement_no']
        if 'binded_mobile' in d:
            o.binded_mobile = d['binded_mobile']
        if 'card_no' in d:
            o.card_no = d['card_no']
        if 'device_no' in d:
            o.device_no = d['device_no']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.MarketingItemSelection import MarketingItemSelection


class MarketingSelectionInfo(object):

    def __init__(self):
        self._selection_list = None
        self._use_mode = None

    @property
    def selection_list(self):
        return self._selection_list

    @selection_list.setter
    def selection_list(self, value):
        if isinstance(value, list):
            self._selection_list = list()
            for i in value:
                if isinstance(i, MarketingItemSelection):
                    self._selection_list.append(i)
                else:
                    self._selection_list.append(MarketingItemSelection.from_alipay_dict(i))
    @property
    def use_mode(self):
        return self._use_mode

    @use_mode.setter
    def use_mode(self, value):
        self._use_mode = value


    def to_alipay_dict(self):
        params = dict()
        if self.selection_list:
            if isinstance(self.selection_list, list):
                for i in range(0, len(self.selection_list)):
                    element = self.selection_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.selection_list[i] = element.to_alipay_dict()
            if hasattr(self.selection_list, 'to_alipay_dict'):
                params['selection_list'] = self.selection_list.to_alipay_dict()
            else:
                params['selection_list'] = self.selection_list
        if self.use_mode:
            if hasattr(self.use_mode, 'to_alipay_dict'):
                params['use_mode'] = self.use_mode.to_alipay_dict()
            else:
                params['use_mode'] = self.use_mode
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = MarketingSelectionInfo()
        if 'selection_list' in d:
            o.selection_list = d['selection_list']
        if 'use_mode' in d:
            o.use_mode = d['use_mode']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.BuyerPayDetail import BuyerPayDetail


class AlipayTradeOrderPayModel(object):

    def __init__(self):
        self._advance_payment_type = None
        self._buyer_id = None
        self._buyer_open_id = None
        self._buyer_pay_detail = None
        self._fulfillment_amount = None
        self._is_async_pay = None
        self._order_pay_mode = None
        self._out_request_no = None
        self._product_code = None
        self._total_amount = None
        self._trade_no = None

    @property
    def advance_payment_type(self):
        return self._advance_payment_type

    @advance_payment_type.setter
    def advance_payment_type(self, value):
        self._advance_payment_type = value
    @property
    def buyer_id(self):
        return self._buyer_id

    @buyer_id.setter
    def buyer_id(self, value):
        self._buyer_id = value
    @property
    def buyer_open_id(self):
        return self._buyer_open_id

    @buyer_open_id.setter
    def buyer_open_id(self, value):
        self._buyer_open_id = value
    @property
    def buyer_pay_detail(self):
        return self._buyer_pay_detail

    @buyer_pay_detail.setter
    def buyer_pay_detail(self, value):
        if isinstance(value, list):
            self._buyer_pay_detail = list()
            for i in value:
                if isinstance(i, BuyerPayDetail):
                    self._buyer_pay_detail.append(i)
                else:
                    self._buyer_pay_detail.append(BuyerPayDetail.from_alipay_dict(i))
    @property
    def fulfillment_amount(self):
        return self._fulfillment_amount

    @fulfillment_amount.setter
    def fulfillment_amount(self, value):
        self._fulfillment_amount = value
    @property
    def is_async_pay(self):
        return self._is_async_pay

    @is_async_pay.setter
    def is_async_pay(self, value):
        self._is_async_pay = value
    @property
    def order_pay_mode(self):
        return self._order_pay_mode

    @order_pay_mode.setter
    def order_pay_mode(self, value):
        self._order_pay_mode = value
    @property
    def out_request_no(self):
        return self._out_request_no

    @out_request_no.setter
    def out_request_no(self, value):
        self._out_request_no = value
    @property
    def product_code(self):
        return self._product_code

    @product_code.setter
    def product_code(self, value):
        self._product_code = value
    @property
    def total_amount(self):
        return self._total_amount

    @total_amount.setter
    def total_amount(self, value):
        self._total_amount = value
    @property
    def trade_no(self):
        return self._trade_no

    @trade_no.setter
    def trade_no(self, value):
        self._trade_no = value


    def to_alipay_dict(self):
        params = dict()
        if self.advance_payment_type:
            if hasattr(self.advance_payment_type, 'to_alipay_dict'):
                params['advance_payment_type'] = self.advance_payment_type.to_alipay_dict()
            else:
                params['advance_payment_type'] = self.advance_payment_type
        if self.buyer_id:
            if hasattr(self.buyer_id, 'to_alipay_dict'):
                params['buyer_id'] = self.buyer_id.to_alipay_dict()
            else:
                params['buyer_id'] = self.buyer_id
        if self.buyer_open_id:
            if hasattr(self.buyer_open_id, 'to_alipay_dict'):
                params['buyer_open_id'] = self.buyer_open_id.to_alipay_dict()
            else:
                params['buyer_open_id'] = self.buyer_open_id
        if self.buyer_pay_detail:
            if isinstance(self.buyer_pay_detail, list):
                for i in range(0, len(self.buyer_pay_detail)):
                    element = self.buyer_pay_detail[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.buyer_pay_detail[i] = element.to_alipay_dict()
            if hasattr(self.buyer_pay_detail, 'to_alipay_dict'):
                params['buyer_pay_detail'] = self.buyer_pay_detail.to_alipay_dict()
            else:
                params['buyer_pay_detail'] = self.buyer_pay_detail
        if self.fulfillment_amount:
            if hasattr(self.fulfillment_amount, 'to_alipay_dict'):
                params['fulfillment_amount'] = self.fulfillment_amount.to_alipay_dict()
            else:
                params['fulfillment_amount'] = self.fulfillment_amount
        if self.is_async_pay:
            if hasattr(self.is_async_pay, 'to_alipay_dict'):
                params['is_async_pay'] = self.is_async_pay.to_alipay_dict()
            else:
                params['is_async_pay'] = self.is_async_pay
        if self.order_pay_mode:
            if hasattr(self.order_pay_mode, 'to_alipay_dict'):
                params['order_pay_mode'] = self.order_pay_mode.to_alipay_dict()
            else:
                params['order_pay_mode'] = self.order_pay_mode
        if self.out_request_no:
            if hasattr(self.out_request_no, 'to_alipay_dict'):
                params['out_request_no'] = self.out_request_no.to_alipay_dict()
            else:
                params['out_request_no'] = self.out_request_no
        if self.product_code:
            if hasattr(self.product_code, 'to_alipay_dict'):
                params['product_code'] = self.product_code.to_alipay_dict()
            else:
                params['product_code'] = self.product_code
        if self.total_amount:
            if hasattr(self.total_amount, 'to_alipay_dict'):
                params['total_amount'] = self.total_amount.to_alipay_dict()
            else:
                params['total_amount'] = self.total_amount
        if self.trade_no:
            if hasattr(self.trade_no, 'to_alipay_dict'):
                params['trade_no'] = self.trade_no.to_alipay_dict()
            else:
                params['trade_no'] = self.trade_no
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayTradeOrderPayModel()
        if 'advance_payment_type' in d:
            o.advance_payment_type = d['advance_payment_type']
        if 'buyer_id' in d:
            o.buyer_id = d['buyer_id']
        if 'buyer_open_id' in d:
            o.buyer_open_id = d['buyer_open_id']
        if 'buyer_pay_detail' in d:
            o.buyer_pay_detail = d['buyer_pay_detail']
        if 'fulfillment_amount' in d:
            o.fulfillment_amount = d['fulfillment_amount']
        if 'is_async_pay' in d:
            o.is_async_pay = d['is_async_pay']
        if 'order_pay_mode' in d:
            o.order_pay_mode = d['order_pay_mode']
        if 'out_request_no' in d:
            o.out_request_no = d['out_request_no']
        if 'product_code' in d:
            o.product_code = d['product_code']
        if 'total_amount' in d:
            o.total_amount = d['total_amount']
        if 'trade_no' in d:
            o.trade_no = d['trade_no']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayBusinessPaymenthubQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayBusinessPaymenthubQueryResponse, self).__init__()
        self._amount = None
        self._channel = None
        self._instruction_id = None
        self._instruction_type = None
        self._out_request_no = None
        self._status = None

    @property
    def amount(self):
        return self._amount

    @amount.setter
    def amount(self, value):
        self._amount = value
    @property
    def channel(self):
        return self._channel

    @channel.setter
    def channel(self, value):
        self._channel = value
    @property
    def instruction_id(self):
        return self._instruction_id

    @instruction_id.setter
    def instruction_id(self, value):
        self._instruction_id = value
    @property
    def instruction_type(self):
        return self._instruction_type

    @instruction_type.setter
    def instruction_type(self, value):
        self._instruction_type = value
    @property
    def out_request_no(self):
        return self._out_request_no

    @out_request_no.setter
    def out_request_no(self, value):
        self._out_request_no = value
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value

    def parse_response_content(self, response_content):
        response = super(AlipayBusinessPaymenthubQueryResponse, self).parse_response_content(response_content)
        if 'amount' in response:
            self.amount = response['amount']
        if 'channel' in response:
            self.channel = response['channel']
        if 'instruction_id' in response:
            self.instruction_id = response['instruction_id']
        if 'instruction_type' in response:
            self.instruction_type = response['instruction_type']
        if 'out_request_no' in response:
            self.out_request_no = response['out_request_no']
        if 'status' in response:
            self.status = response['status']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class TimeCardSimpleItemInfo(object):

    def __init__(self):
        self._desc = None
        self._item_id = None
        self._logo = None
        self._original_price = None
        self._price = None
        self._times = None
        self._title = None

    @property
    def desc(self):
        return self._desc

    @desc.setter
    def desc(self, value):
        self._desc = value
    @property
    def item_id(self):
        return self._item_id

    @item_id.setter
    def item_id(self, value):
        self._item_id = value
    @property
    def logo(self):
        return self._logo

    @logo.setter
    def logo(self, value):
        self._logo = value
    @property
    def original_price(self):
        return self._original_price

    @original_price.setter
    def original_price(self, value):
        self._original_price = value
    @property
    def price(self):
        return self._price

    @price.setter
    def price(self, value):
        self._price = value
    @property
    def times(self):
        return self._times

    @times.setter
    def times(self, value):
        self._times = value
    @property
    def title(self):
        return self._title

    @title.setter
    def title(self, value):
        self._title = value


    def to_alipay_dict(self):
        params = dict()
        if self.desc:
            if hasattr(self.desc, 'to_alipay_dict'):
                params['desc'] = self.desc.to_alipay_dict()
            else:
                params['desc'] = self.desc
        if self.item_id:
            if hasattr(self.item_id, 'to_alipay_dict'):
                params['item_id'] = self.item_id.to_alipay_dict()
            else:
                params['item_id'] = self.item_id
        if self.logo:
            if hasattr(self.logo, 'to_alipay_dict'):
                params['logo'] = self.logo.to_alipay_dict()
            else:
                params['logo'] = self.logo
        if self.original_price:
            if hasattr(self.original_price, 'to_alipay_dict'):
                params['original_price'] = self.original_price.to_alipay_dict()
            else:
                params['original_price'] = self.original_price
        if self.price:
            if hasattr(self.price, 'to_alipay_dict'):
                params['price'] = self.price.to_alipay_dict()
            else:
                params['price'] = self.price
        if self.times:
            if hasattr(self.times, 'to_alipay_dict'):
                params['times'] = self.times.to_alipay_dict()
            else:
                params['times'] = self.times
        if self.title:
            if hasattr(self.title, 'to_alipay_dict'):
                params['title'] = self.title.to_alipay_dict()
            else:
                params['title'] = self.title
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = TimeCardSimpleItemInfo()
        if 'desc' in d:
            o.desc = d['desc']
        if 'item_id' in d:
            o.item_id = d['item_id']
        if 'logo' in d:
            o.logo = d['logo']
        if 'original_price' in d:
            o.original_price = d['original_price']
        if 'price' in d:
            o.price = d['price']
        if 'times' in d:
            o.times = d['times']
        if 'title' in d:
            o.title = d['title']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.ClassRateInfo import ClassRateInfo
from alipay.aop.api.domain.ClassRateInfo import ClassRateInfo


class AlipayOverseasTravelRateRateinfoQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayOverseasTravelRateRateinfoQueryResponse, self).__init__()
        self._benefit_rate_list = None
        self._contrast_rate = None
        self._contrast_rate_amount = None
        self._currency = None
        self._currency_icon = None
        self._member_rate_list = None
        self._rate_desc = None
        self._rate_source = None
        self._user_benefit_grade = None
        self._user_member_grade = None
        self._user_rate = None
        self._user_rate_amount = None

    @property
    def benefit_rate_list(self):
        return self._benefit_rate_list

    @benefit_rate_list.setter
    def benefit_rate_list(self, value):
        if isinstance(value, list):
            self._benefit_rate_list = list()
            for i in value:
                if isinstance(i, ClassRateInfo):
                    self._benefit_rate_list.append(i)
                else:
                    self._benefit_rate_list.append(ClassRateInfo.from_alipay_dict(i))
    @property
    def contrast_rate(self):
        return self._contrast_rate

    @contrast_rate.setter
    def contrast_rate(self, value):
        self._contrast_rate = value
    @property
    def contrast_rate_amount(self):
        return self._contrast_rate_amount

    @contrast_rate_amount.setter
    def contrast_rate_amount(self, value):
        self._contrast_rate_amount = value
    @property
    def currency(self):
        return self._currency

    @currency.setter
    def currency(self, value):
        self._currency = value
    @property
    def currency_icon(self):
        return self._currency_icon

    @currency_icon.setter
    def currency_icon(self, value):
        self._currency_icon = value
    @property
    def member_rate_list(self):
        return self._member_rate_list

    @member_rate_list.setter
    def member_rate_list(self, value):
        if isinstance(value, list):
            self._member_rate_list = list()
            for i in value:
                if isinstance(i, ClassRateInfo):
                    self._member_rate_list.append(i)
                else:
                    self._member_rate_list.append(ClassRateInfo.from_alipay_dict(i))
    @property
    def rate_desc(self):
        return self._rate_desc

    @rate_desc.setter
    def rate_desc(self, value):
        self._rate_desc = value
    @property
    def rate_source(self):
        return self._rate_source

    @rate_source.setter
    def rate_source(self, value):
        self._rate_source = value
    @property
    def user_benefit_grade(self):
        return self._user_benefit_grade

    @user_benefit_grade.setter
    def user_benefit_grade(self, value):
        self._user_benefit_grade = value
    @property
    def user_member_grade(self):
        return self._user_member_grade

    @user_member_grade.setter
    def user_member_grade(self, value):
        self._user_member_grade = value
    @property
    def user_rate(self):
        return self._user_rate

    @user_rate.setter
    def user_rate(self, value):
        self._user_rate = value
    @property
    def user_rate_amount(self):
        return self._user_rate_amount

    @user_rate_amount.setter
    def user_rate_amount(self, value):
        self._user_rate_amount = value

    def parse_response_content(self, response_content):
        response = super(AlipayOverseasTravelRateRateinfoQueryResponse, self).parse_response_content(response_content)
        if 'benefit_rate_list' in response:
            self.benefit_rate_list = response['benefit_rate_list']
        if 'contrast_rate' in response:
            self.contrast_rate = response['contrast_rate']
        if 'contrast_rate_amount' in response:
            self.contrast_rate_amount = response['contrast_rate_amount']
        if 'currency' in response:
            self.currency = response['currency']
        if 'currency_icon' in response:
            self.currency_icon = response['currency_icon']
        if 'member_rate_list' in response:
            self.member_rate_list = response['member_rate_list']
        if 'rate_desc' in response:
            self.rate_desc = response['rate_desc']
        if 'rate_source' in response:
            self.rate_source = response['rate_source']
        if 'user_benefit_grade' in response:
            self.user_benefit_grade = response['user_benefit_grade']
        if 'user_member_grade' in response:
            self.user_member_grade = response['user_member_grade']
        if 'user_rate' in response:
            self.user_rate = response['user_rate']
        if 'user_rate_amount' in response:
            self.user_rate_amount = response['user_rate_amount']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayFundTaxbillSignQueryModel(object):

    def __init__(self):
        self._biz_scene = None
        self._contractor_code = None
        self._employer_code = None
        self._identification_in_belonging_employer = None
        self._product_code = None

    @property
    def biz_scene(self):
        return self._biz_scene

    @biz_scene.setter
    def biz_scene(self, value):
        self._biz_scene = value
    @property
    def contractor_code(self):
        return self._contractor_code

    @contractor_code.setter
    def contractor_code(self, value):
        self._contractor_code = value
    @property
    def employer_code(self):
        return self._employer_code

    @employer_code.setter
    def employer_code(self, value):
        self._employer_code = value
    @property
    def identification_in_belonging_employer(self):
        return self._identification_in_belonging_employer

    @identification_in_belonging_employer.setter
    def identification_in_belonging_employer(self, value):
        self._identification_in_belonging_employer = value
    @property
    def product_code(self):
        return self._product_code

    @product_code.setter
    def product_code(self, value):
        self._product_code = value


    def to_alipay_dict(self):
        params = dict()
        if self.biz_scene:
            if hasattr(self.biz_scene, 'to_alipay_dict'):
                params['biz_scene'] = self.biz_scene.to_alipay_dict()
            else:
                params['biz_scene'] = self.biz_scene
        if self.contractor_code:
            if hasattr(self.contractor_code, 'to_alipay_dict'):
                params['contractor_code'] = self.contractor_code.to_alipay_dict()
            else:
                params['contractor_code'] = self.contractor_code
        if self.employer_code:
            if hasattr(self.employer_code, 'to_alipay_dict'):
                params['employer_code'] = self.employer_code.to_alipay_dict()
            else:
                params['employer_code'] = self.employer_code
        if self.identification_in_belonging_employer:
            if hasattr(self.identification_in_belonging_employer, 'to_alipay_dict'):
                params['identification_in_belonging_employer'] = self.identification_in_belonging_employer.to_alipay_dict()
            else:
                params['identification_in_belonging_employer'] = self.identification_in_belonging_employer
        if self.product_code:
            if hasattr(self.product_code, 'to_alipay_dict'):
                params['product_code'] = self.product_code.to_alipay_dict()
            else:
                params['product_code'] = self.product_code
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayFundTaxbillSignQueryModel()
        if 'biz_scene' in d:
            o.biz_scene = d['biz_scene']
        if 'contractor_code' in d:
            o.contractor_code = d['contractor_code']
        if 'employer_code' in d:
            o.employer_code = d['employer_code']
        if 'identification_in_belonging_employer' in d:
            o.identification_in_belonging_employer = d['identification_in_belonging_employer']
        if 'product_code' in d:
            o.product_code = d['product_code']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayEbppInvoiceFileOutputQueryModel(object):

    def __init__(self):
        self._invoice_code = None
        self._invoice_no = None
        self._open_id = None
        self._scene = None
        self._skip_expense_progress_sync = None
        self._user_id = None

    @property
    def invoice_code(self):
        return self._invoice_code

    @invoice_code.setter
    def invoice_code(self, value):
        self._invoice_code = value
    @property
    def invoice_no(self):
        return self._invoice_no

    @invoice_no.setter
    def invoice_no(self, value):
        self._invoice_no = value
    @property
    def open_id(self):
        return self._open_id

    @open_id.setter
    def open_id(self, value):
        self._open_id = value
    @property
    def scene(self):
        return self._scene

    @scene.setter
    def scene(self, value):
        self._scene = value
    @property
    def skip_expense_progress_sync(self):
        return self._skip_expense_progress_sync

    @skip_expense_progress_sync.setter
    def skip_expense_progress_sync(self, value):
        self._skip_expense_progress_sync = value
    @property
    def user_id(self):
        return self._user_id

    @user_id.setter
    def user_id(self, value):
        self._user_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.invoice_code:
            if hasattr(self.invoice_code, 'to_alipay_dict'):
                params['invoice_code'] = self.invoice_code.to_alipay_dict()
            else:
                params['invoice_code'] = self.invoice_code
        if self.invoice_no:
            if hasattr(self.invoice_no, 'to_alipay_dict'):
                params['invoice_no'] = self.invoice_no.to_alipay_dict()
            else:
                params['invoice_no'] = self.invoice_no
        if self.open_id:
            if hasattr(self.open_id, 'to_alipay_dict'):
                params['open_id'] = self.open_id.to_alipay_dict()
            else:
                params['open_id'] = self.open_id
        if self.scene:
            if hasattr(self.scene, 'to_alipay_dict'):
                params['scene'] = self.scene.to_alipay_dict()
            else:
                params['scene'] = self.scene
        if self.skip_expense_progress_sync:
            if hasattr(self.skip_expense_progress_sync, 'to_alipay_dict'):
                params['skip_expense_progress_sync'] = self.skip_expense_progress_sync.to_alipay_dict()
            else:
                params['skip_expense_progress_sync'] = self.skip_expense_progress_sync
        if self.user_id:
            if hasattr(self.user_id, 'to_alipay_dict'):
                params['user_id'] = self.user_id.to_alipay_dict()
            else:
                params['user_id'] = self.user_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayEbppInvoiceFileOutputQueryModel()
        if 'invoice_code' in d:
            o.invoice_code = d['invoice_code']
        if 'invoice_no' in d:
            o.invoice_no = d['invoice_no']
        if 'open_id' in d:
            o.open_id = d['open_id']
        if 'scene' in d:
            o.scene = d['scene']
        if 'skip_expense_progress_sync' in d:
            o.skip_expense_progress_sync = d['skip_expense_progress_sync']
        if 'user_id' in d:
            o.user_id = d['user_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayCommerceTransportEtcSellerconfigQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayCommerceTransportEtcSellerconfigQueryResponse, self).__init__()
        self._query_results = None

    @property
    def query_results(self):
        return self._query_results

    @query_results.setter
    def query_results(self, value):
        self._query_results = value

    def parse_response_content(self, response_content):
        response = super(AlipayCommerceTransportEtcSellerconfigQueryResponse, self).parse_response_content(response_content)
        if 'query_results' in response:
            self.query_results = response['query_results']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayEbppEbppBillkeyDeductUpgradeResponse(AlipayResponse):

    def __init__(self):
        super(AlipayEbppEbppBillkeyDeductUpgradeResponse, self).__init__()
        self._submit_res = None

    @property
    def submit_res(self):
        return self._submit_res

    @submit_res.setter
    def submit_res(self, value):
        self._submit_res = value

    def parse_response_content(self, response_content):
        response = super(AlipayEbppEbppBillkeyDeductUpgradeResponse, self).parse_response_content(response_content)
        if 'submit_res' in response:
            self.submit_res = response['submit_res']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AntMerchantMemberwalletWalletQueryResponse(AlipayResponse):

    def __init__(self):
        super(AntMerchantMemberwalletWalletQueryResponse, self).__init__()
        self._open = None
        self._open_time = None
        self._open_url = None
        self._wallet_id = None

    @property
    def open(self):
        return self._open

    @open.setter
    def open(self, value):
        self._open = value
    @property
    def open_time(self):
        return self._open_time

    @open_time.setter
    def open_time(self, value):
        self._open_time = value
    @property
    def open_url(self):
        return self._open_url

    @open_url.setter
    def open_url(self, value):
        self._open_url = value
    @property
    def wallet_id(self):
        return self._wallet_id

    @wallet_id.setter
    def wallet_id(self, value):
        self._wallet_id = value

    def parse_response_content(self, response_content):
        response = super(AntMerchantMemberwalletWalletQueryResponse, self).parse_response_content(response_content)
        if 'open' in response:
            self.open = response['open']
        if 'open_time' in response:
            self.open_time = response['open_time']
        if 'open_url' in response:
            self.open_url = response['open_url']
        if 'wallet_id' in response:
            self.wallet_id = response['wallet_id']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class ZhimaCreditPayafteruseCreditagreementQueryModel(object):

    def __init__(self):
        self._credit_agreement_id = None
        self._out_agreement_no = None

    @property
    def credit_agreement_id(self):
        return self._credit_agreement_id

    @credit_agreement_id.setter
    def credit_agreement_id(self, value):
        self._credit_agreement_id = value
    @property
    def out_agreement_no(self):
        return self._out_agreement_no

    @out_agreement_no.setter
    def out_agreement_no(self, value):
        self._out_agreement_no = value


    def to_alipay_dict(self):
        params = dict()
        if self.credit_agreement_id:
            if hasattr(self.credit_agreement_id, 'to_alipay_dict'):
                params['credit_agreement_id'] = self.credit_agreement_id.to_alipay_dict()
            else:
                params['credit_agreement_id'] = self.credit_agreement_id
        if self.out_agreement_no:
            if hasattr(self.out_agreement_no, 'to_alipay_dict'):
                params['out_agreement_no'] = self.out_agreement_no.to_alipay_dict()
            else:
                params['out_agreement_no'] = self.out_agreement_no
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = ZhimaCreditPayafteruseCreditagreementQueryModel()
        if 'credit_agreement_id' in d:
            o.credit_agreement_id = d['credit_agreement_id']
        if 'out_agreement_no' in d:
            o.out_agreement_no = d['out_agreement_no']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.RcSmartResponse import RcSmartResponse


class AlipayFincoreComplianceRcservcenterRcsmartApproveResponse(AlipayResponse):

    def __init__(self):
        super(AlipayFincoreComplianceRcservcenterRcsmartApproveResponse, self).__init__()
        self._rc_smart_response = None

    @property
    def rc_smart_response(self):
        return self._rc_smart_response

    @rc_smart_response.setter
    def rc_smart_response(self, value):
        if isinstance(value, RcSmartResponse):
            self._rc_smart_response = value
        else:
            self._rc_smart_response = RcSmartResponse.from_alipay_dict(value)

    def parse_response_content(self, response_content):
        response = super(AlipayFincoreComplianceRcservcenterRcsmartApproveResponse, self).parse_response_content(response_content)
        if 'rc_smart_response' in response:
            self.rc_smart_response = response['rc_smart_response']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class GoodsOrder(object):

    def __init__(self):
        self._goods_name = None
        self._goods_picture_id = None

    @property
    def goods_name(self):
        return self._goods_name

    @goods_name.setter
    def goods_name(self, value):
        self._goods_name = value
    @property
    def goods_picture_id(self):
        return self._goods_picture_id

    @goods_picture_id.setter
    def goods_picture_id(self, value):
        self._goods_picture_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.goods_name:
            if hasattr(self.goods_name, 'to_alipay_dict'):
                params['goods_name'] = self.goods_name.to_alipay_dict()
            else:
                params['goods_name'] = self.goods_name
        if self.goods_picture_id:
            if hasattr(self.goods_picture_id, 'to_alipay_dict'):
                params['goods_picture_id'] = self.goods_picture_id.to_alipay_dict()
            else:
                params['goods_picture_id'] = self.goods_picture_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = GoodsOrder()
        if 'goods_name' in d:
            o.goods_name = d['goods_name']
        if 'goods_picture_id' in d:
            o.goods_picture_id = d['goods_picture_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class ZMGOCycleWithholdConfig(object):

    def __init__(self):
        self._deduct_plan = None
        self._exemption_period = None
        self._period = None
        self._period_type = None
        self._support_cycle_withhold_high_mode = None
        self._support_exemption_period = None
        self._withhold_mode = None

    @property
    def deduct_plan(self):
        return self._deduct_plan

    @deduct_plan.setter
    def deduct_plan(self, value):
        if isinstance(value, list):
            self._deduct_plan = list()
            for i in value:
                self._deduct_plan.append(i)
    @property
    def exemption_period(self):
        return self._exemption_period

    @exemption_period.setter
    def exemption_period(self, value):
        self._exemption_period = value
    @property
    def period(self):
        return self._period

    @period.setter
    def period(self, value):
        self._period = value
    @property
    def period_type(self):
        return self._period_type

    @period_type.setter
    def period_type(self, value):
        self._period_type = value
    @property
    def support_cycle_withhold_high_mode(self):
        return self._support_cycle_withhold_high_mode

    @support_cycle_withhold_high_mode.setter
    def support_cycle_withhold_high_mode(self, value):
        self._support_cycle_withhold_high_mode = value
    @property
    def support_exemption_period(self):
        return self._support_exemption_period

    @support_exemption_period.setter
    def support_exemption_period(self, value):
        self._support_exemption_period = value
    @property
    def withhold_mode(self):
        return self._withhold_mode

    @withhold_mode.setter
    def withhold_mode(self, value):
        self._withhold_mode = value


    def to_alipay_dict(self):
        params = dict()
        if self.deduct_plan:
            if isinstance(self.deduct_plan, list):
                for i in range(0, len(self.deduct_plan)):
                    element = self.deduct_plan[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.deduct_plan[i] = element.to_alipay_dict()
            if hasattr(self.deduct_plan, 'to_alipay_dict'):
                params['deduct_plan'] = self.deduct_plan.to_alipay_dict()
            else:
                params['deduct_plan'] = self.deduct_plan
        if self.exemption_period:
            if hasattr(self.exemption_period, 'to_alipay_dict'):
                params['exemption_period'] = self.exemption_period.to_alipay_dict()
            else:
                params['exemption_period'] = self.exemption_period
        if self.period:
            if hasattr(self.period, 'to_alipay_dict'):
                params['period'] = self.period.to_alipay_dict()
            else:
                params['period'] = self.period
        if self.period_type:
            if hasattr(self.period_type, 'to_alipay_dict'):
                params['period_type'] = self.period_type.to_alipay_dict()
            else:
                params['period_type'] = self.period_type
        if self.support_cycle_withhold_high_mode:
            if hasattr(self.support_cycle_withhold_high_mode, 'to_alipay_dict'):
                params['support_cycle_withhold_high_mode'] = self.support_cycle_withhold_high_mode.to_alipay_dict()
            else:
                params['support_cycle_withhold_high_mode'] = self.support_cycle_withhold_high_mode
        if self.support_exemption_period:
            if hasattr(self.support_exemption_period, 'to_alipay_dict'):
                params['support_exemption_period'] = self.support_exemption_period.to_alipay_dict()
            else:
                params['support_exemption_period'] = self.support_exemption_period
        if self.withhold_mode:
            if hasattr(self.withhold_mode, 'to_alipay_dict'):
                params['withhold_mode'] = self.withhold_mode.to_alipay_dict()
            else:
                params['withhold_mode'] = self.withhold_mode
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = ZMGOCycleWithholdConfig()
        if 'deduct_plan' in d:
            o.deduct_plan = d['deduct_plan']
        if 'exemption_period' in d:
            o.exemption_period = d['exemption_period']
        if 'period' in d:
            o.period = d['period']
        if 'period_type' in d:
            o.period_type = d['period_type']
        if 'support_cycle_withhold_high_mode' in d:
            o.support_cycle_withhold_high_mode = d['support_cycle_withhold_high_mode']
        if 'support_exemption_period' in d:
            o.support_exemption_period = d['support_exemption_period']
        if 'withhold_mode' in d:
            o.withhold_mode = d['withhold_mode']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayUserElectronicidMerchantbarcodeCreateModel(object):

    def __init__(self):
        self._expire_time = None
        self._type = None
        self._unique_id = None

    @property
    def expire_time(self):
        return self._expire_time

    @expire_time.setter
    def expire_time(self, value):
        self._expire_time = value
    @property
    def type(self):
        return self._type

    @type.setter
    def type(self, value):
        self._type = value
    @property
    def unique_id(self):
        return self._unique_id

    @unique_id.setter
    def unique_id(self, value):
        self._unique_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.expire_time:
            if hasattr(self.expire_time, 'to_alipay_dict'):
                params['expire_time'] = self.expire_time.to_alipay_dict()
            else:
                params['expire_time'] = self.expire_time
        if self.type:
            if hasattr(self.type, 'to_alipay_dict'):
                params['type'] = self.type.to_alipay_dict()
            else:
                params['type'] = self.type
        if self.unique_id:
            if hasattr(self.unique_id, 'to_alipay_dict'):
                params['unique_id'] = self.unique_id.to_alipay_dict()
            else:
                params['unique_id'] = self.unique_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayUserElectronicidMerchantbarcodeCreateModel()
        if 'expire_time' in d:
            o.expire_time = d['expire_time']
        if 'type' in d:
            o.type = d['type']
        if 'unique_id' in d:
            o.unique_id = d['unique_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayEbppJfexportChargeinstQueryModel(object):

    def __init__(self):
        self._biz_type = None
        self._extend_field = None
        self._page = None
        self._page_query = None
        self._page_size = None
        self._sub_biz_type = None

    @property
    def biz_type(self):
        return self._biz_type

    @biz_type.setter
    def biz_type(self, value):
        self._biz_type = value
    @property
    def extend_field(self):
        return self._extend_field

    @extend_field.setter
    def extend_field(self, value):
        self._extend_field = value
    @property
    def page(self):
        return self._page

    @page.setter
    def page(self, value):
        self._page = value
    @property
    def page_query(self):
        return self._page_query

    @page_query.setter
    def page_query(self, value):
        self._page_query = value
    @property
    def page_size(self):
        return self._page_size

    @page_size.setter
    def page_size(self, value):
        self._page_size = value
    @property
    def sub_biz_type(self):
        return self._sub_biz_type

    @sub_biz_type.setter
    def sub_biz_type(self, value):
        self._sub_biz_type = value


    def to_alipay_dict(self):
        params = dict()
        if self.biz_type:
            if hasattr(self.biz_type, 'to_alipay_dict'):
                params['biz_type'] = self.biz_type.to_alipay_dict()
            else:
                params['biz_type'] = self.biz_type
        if self.extend_field:
            if hasattr(self.extend_field, 'to_alipay_dict'):
                params['extend_field'] = self.extend_field.to_alipay_dict()
            else:
                params['extend_field'] = self.extend_field
        if self.page:
            if hasattr(self.page, 'to_alipay_dict'):
                params['page'] = self.page.to_alipay_dict()
            else:
                params['page'] = self.page
        if self.page_query:
            if hasattr(self.page_query, 'to_alipay_dict'):
                params['page_query'] = self.page_query.to_alipay_dict()
            else:
                params['page_query'] = self.page_query
        if self.page_size:
            if hasattr(self.page_size, 'to_alipay_dict'):
                params['page_size'] = self.page_size.to_alipay_dict()
            else:
                params['page_size'] = self.page_size
        if self.sub_biz_type:
            if hasattr(self.sub_biz_type, 'to_alipay_dict'):
                params['sub_biz_type'] = self.sub_biz_type.to_alipay_dict()
            else:
                params['sub_biz_type'] = self.sub_biz_type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayEbppJfexportChargeinstQueryModel()
        if 'biz_type' in d:
            o.biz_type = d['biz_type']
        if 'extend_field' in d:
            o.extend_field = d['extend_field']
        if 'page' in d:
            o.page = d['page']
        if 'page_query' in d:
            o.page_query = d['page_query']
        if 'page_size' in d:
            o.page_size = d['page_size']
        if 'sub_biz_type' in d:
            o.sub_biz_type = d['sub_biz_type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayCommerceTransportEtcRefundQueryModel(object):

    def __init__(self):
        self._biz_agreement_no = None
        self._out_order_id = None
        self._out_request_no = None

    @property
    def biz_agreement_no(self):
        return self._biz_agreement_no

    @biz_agreement_no.setter
    def biz_agreement_no(self, value):
        self._biz_agreement_no = value
    @property
    def out_order_id(self):
        return self._out_order_id

    @out_order_id.setter
    def out_order_id(self, value):
        self._out_order_id = value
    @property
    def out_request_no(self):
        return self._out_request_no

    @out_request_no.setter
    def out_request_no(self, value):
        self._out_request_no = value


    def to_alipay_dict(self):
        params = dict()
        if self.biz_agreement_no:
            if hasattr(self.biz_agreement_no, 'to_alipay_dict'):
                params['biz_agreement_no'] = self.biz_agreement_no.to_alipay_dict()
            else:
                params['biz_agreement_no'] = self.biz_agreement_no
        if self.out_order_id:
            if hasattr(self.out_order_id, 'to_alipay_dict'):
                params['out_order_id'] = self.out_order_id.to_alipay_dict()
            else:
                params['out_order_id'] = self.out_order_id
        if self.out_request_no:
            if hasattr(self.out_request_no, 'to_alipay_dict'):
                params['out_request_no'] = self.out_request_no.to_alipay_dict()
            else:
                params['out_request_no'] = self.out_request_no
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayCommerceTransportEtcRefundQueryModel()
        if 'biz_agreement_no' in d:
            o.biz_agreement_no = d['biz_agreement_no']
        if 'out_order_id' in d:
            o.out_order_id = d['out_order_id']
        if 'out_request_no' in d:
            o.out_request_no = d['out_request_no']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class ZhimaCreditPeZmgoAgreementUnsignModel(object):

    def __init__(self):
        self._agreement_id = None
        self._alipay_user_id = None
        self._open_id = None
        self._partner_id = None
        self._quit_type = None

    @property
    def agreement_id(self):
        return self._agreement_id

    @agreement_id.setter
    def agreement_id(self, value):
        self._agreement_id = value
    @property
    def alipay_user_id(self):
        return self._alipay_user_id

    @alipay_user_id.setter
    def alipay_user_id(self, value):
        self._alipay_user_id = value
    @property
    def open_id(self):
        return self._open_id

    @open_id.setter
    def open_id(self, value):
        self._open_id = value
    @property
    def partner_id(self):
        return self._partner_id

    @partner_id.setter
    def partner_id(self, value):
        self._partner_id = value
    @property
    def quit_type(self):
        return self._quit_type

    @quit_type.setter
    def quit_type(self, value):
        self._quit_type = value


    def to_alipay_dict(self):
        params = dict()
        if self.agreement_id:
            if hasattr(self.agreement_id, 'to_alipay_dict'):
                params['agreement_id'] = self.agreement_id.to_alipay_dict()
            else:
                params['agreement_id'] = self.agreement_id
        if self.alipay_user_id:
            if hasattr(self.alipay_user_id, 'to_alipay_dict'):
                params['alipay_user_id'] = self.alipay_user_id.to_alipay_dict()
            else:
                params['alipay_user_id'] = self.alipay_user_id
        if self.open_id:
            if hasattr(self.open_id, 'to_alipay_dict'):
                params['open_id'] = self.open_id.to_alipay_dict()
            else:
                params['open_id'] = self.open_id
        if self.partner_id:
            if hasattr(self.partner_id, 'to_alipay_dict'):
                params['partner_id'] = self.partner_id.to_alipay_dict()
            else:
                params['partner_id'] = self.partner_id
        if self.quit_type:
            if hasattr(self.quit_type, 'to_alipay_dict'):
                params['quit_type'] = self.quit_type.to_alipay_dict()
            else:
                params['quit_type'] = self.quit_type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = ZhimaCreditPeZmgoAgreementUnsignModel()
        if 'agreement_id' in d:
            o.agreement_id = d['agreement_id']
        if 'alipay_user_id' in d:
            o.alipay_user_id = d['alipay_user_id']
        if 'open_id' in d:
            o.open_id = d['open_id']
        if 'partner_id' in d:
            o.partner_id = d['partner_id']
        if 'quit_type' in d:
            o.quit_type = d['quit_type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayCommerceCityfacilitatorVoucherGenerateModel(object):

    def __init__(self):
        self._city_code = None
        self._site_begin = None
        self._site_end = None
        self._ticket_num = None
        self._ticket_price = None
        self._ticket_type = None
        self._total_fee = None
        self._trade_no = None

    @property
    def city_code(self):
        return self._city_code

    @city_code.setter
    def city_code(self, value):
        self._city_code = value
    @property
    def site_begin(self):
        return self._site_begin

    @site_begin.setter
    def site_begin(self, value):
        self._site_begin = value
    @property
    def site_end(self):
        return self._site_end

    @site_end.setter
    def site_end(self, value):
        self._site_end = value
    @property
    def ticket_num(self):
        return self._ticket_num

    @ticket_num.setter
    def ticket_num(self, value):
        self._ticket_num = value
    @property
    def ticket_price(self):
        return self._ticket_price

    @ticket_price.setter
    def ticket_price(self, value):
        self._ticket_price = value
    @property
    def ticket_type(self):
        return self._ticket_type

    @ticket_type.setter
    def ticket_type(self, value):
        self._ticket_type = value
    @property
    def total_fee(self):
        return self._total_fee

    @total_fee.setter
    def total_fee(self, value):
        self._total_fee = value
    @property
    def trade_no(self):
        return self._trade_no

    @trade_no.setter
    def trade_no(self, value):
        self._trade_no = value


    def to_alipay_dict(self):
        params = dict()
        if self.city_code:
            if hasattr(self.city_code, 'to_alipay_dict'):
                params['city_code'] = self.city_code.to_alipay_dict()
            else:
                params['city_code'] = self.city_code
        if self.site_begin:
            if hasattr(self.site_begin, 'to_alipay_dict'):
                params['site_begin'] = self.site_begin.to_alipay_dict()
            else:
                params['site_begin'] = self.site_begin
        if self.site_end:
            if hasattr(self.site_end, 'to_alipay_dict'):
                params['site_end'] = self.site_end.to_alipay_dict()
            else:
                params['site_end'] = self.site_end
        if self.ticket_num:
            if hasattr(self.ticket_num, 'to_alipay_dict'):
                params['ticket_num'] = self.ticket_num.to_alipay_dict()
            else:
                params['ticket_num'] = self.ticket_num
        if self.ticket_price:
            if hasattr(self.ticket_price, 'to_alipay_dict'):
                params['ticket_price'] = self.ticket_price.to_alipay_dict()
            else:
                params['ticket_price'] = self.ticket_price
        if self.ticket_type:
            if hasattr(self.ticket_type, 'to_alipay_dict'):
                params['ticket_type'] = self.ticket_type.to_alipay_dict()
            else:
                params['ticket_type'] = self.ticket_type
        if self.total_fee:
            if hasattr(self.total_fee, 'to_alipay_dict'):
                params['total_fee'] = self.total_fee.to_alipay_dict()
            else:
                params['total_fee'] = self.total_fee
        if self.trade_no:
            if hasattr(self.trade_no, 'to_alipay_dict'):
                params['trade_no'] = self.trade_no.to_alipay_dict()
            else:
                params['trade_no'] = self.trade_no
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayCommerceCityfacilitatorVoucherGenerateModel()
        if 'city_code' in d:
            o.city_code = d['city_code']
        if 'site_begin' in d:
            o.site_begin = d['site_begin']
        if 'site_end' in d:
            o.site_end = d['site_end']
        if 'ticket_num' in d:
            o.ticket_num = d['ticket_num']
        if 'ticket_price' in d:
            o.ticket_price = d['ticket_price']
        if 'ticket_type' in d:
            o.ticket_type = d['ticket_type']
        if 'total_fee' in d:
            o.total_fee = d['total_fee']
        if 'trade_no' in d:
            o.trade_no = d['trade_no']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.EnterpriseCustomerInfoVO import EnterpriseCustomerInfoVO
from alipay.aop.api.domain.CreditPayMoneyVO import CreditPayMoneyVO
from alipay.aop.api.domain.ReceiveInfoVO import ReceiveInfoVO


class MybankCreditLoantradeGuarletterNewinvoiceApplyModel(object):

    def __init__(self):
        self._apply_user_info = None
        self._guar_order_no = None
        self._invoice_amt = None
        self._invoice_type = None
        self._receive_info = None
        self._request_id = None

    @property
    def apply_user_info(self):
        return self._apply_user_info

    @apply_user_info.setter
    def apply_user_info(self, value):
        if isinstance(value, EnterpriseCustomerInfoVO):
            self._apply_user_info = value
        else:
            self._apply_user_info = EnterpriseCustomerInfoVO.from_alipay_dict(value)
    @property
    def guar_order_no(self):
        return self._guar_order_no

    @guar_order_no.setter
    def guar_order_no(self, value):
        self._guar_order_no = value
    @property
    def invoice_amt(self):
        return self._invoice_amt

    @invoice_amt.setter
    def invoice_amt(self, value):
        if isinstance(value, CreditPayMoneyVO):
            self._invoice_amt = value
        else:
            self._invoice_amt = CreditPayMoneyVO.from_alipay_dict(value)
    @property
    def invoice_type(self):
        return self._invoice_type

    @invoice_type.setter
    def invoice_type(self, value):
        self._invoice_type = value
    @property
    def receive_info(self):
        return self._receive_info

    @receive_info.setter
    def receive_info(self, value):
        if isinstance(value, ReceiveInfoVO):
            self._receive_info = value
        else:
            self._receive_info = ReceiveInfoVO.from_alipay_dict(value)
    @property
    def request_id(self):
        return self._request_id

    @request_id.setter
    def request_id(self, value):
        self._request_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.apply_user_info:
            if hasattr(self.apply_user_info, 'to_alipay_dict'):
                params['apply_user_info'] = self.apply_user_info.to_alipay_dict()
            else:
                params['apply_user_info'] = self.apply_user_info
        if self.guar_order_no:
            if hasattr(self.guar_order_no, 'to_alipay_dict'):
                params['guar_order_no'] = self.guar_order_no.to_alipay_dict()
            else:
                params['guar_order_no'] = self.guar_order_no
        if self.invoice_amt:
            if hasattr(self.invoice_amt, 'to_alipay_dict'):
                params['invoice_amt'] = self.invoice_amt.to_alipay_dict()
            else:
                params['invoice_amt'] = self.invoice_amt
        if self.invoice_type:
            if hasattr(self.invoice_type, 'to_alipay_dict'):
                params['invoice_type'] = self.invoice_type.to_alipay_dict()
            else:
                params['invoice_type'] = self.invoice_type
        if self.receive_info:
            if hasattr(self.receive_info, 'to_alipay_dict'):
                params['receive_info'] = self.receive_info.to_alipay_dict()
            else:
                params['receive_info'] = self.receive_info
        if self.request_id:
            if hasattr(self.request_id, 'to_alipay_dict'):
                params['request_id'] = self.request_id.to_alipay_dict()
            else:
                params['request_id'] = self.request_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = MybankCreditLoantradeGuarletterNewinvoiceApplyModel()
        if 'apply_user_info' in d:
            o.apply_user_info = d['apply_user_info']
        if 'guar_order_no' in d:
            o.guar_order_no = d['guar_order_no']
        if 'invoice_amt' in d:
            o.invoice_amt = d['invoice_amt']
        if 'invoice_type' in d:
            o.invoice_type = d['invoice_type']
        if 'receive_info' in d:
            o.receive_info = d['receive_info']
        if 'request_id' in d:
            o.request_id = d['request_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class SsdataDataserviceRiskRtopQueryResponse(AlipayResponse):

    def __init__(self):
        super(SsdataDataserviceRiskRtopQueryResponse, self).__init__()
        self._query_result = None
        self._success = None
        self._unique_id = None

    @property
    def query_result(self):
        return self._query_result

    @query_result.setter
    def query_result(self, value):
        self._query_result = value
    @property
    def success(self):
        return self._success

    @success.setter
    def success(self, value):
        self._success = value
    @property
    def unique_id(self):
        return self._unique_id

    @unique_id.setter
    def unique_id(self, value):
        self._unique_id = value

    def parse_response_content(self, response_content):
        response = super(SsdataDataserviceRiskRtopQueryResponse, self).parse_response_content(response_content)
        if 'query_result' in response:
            self.query_result = response['query_result']
        if 'success' in response:
            self.success = response['success']
        if 'unique_id' in response:
            self.unique_id = response['unique_id']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class CommercializationSyncDataReq(object):

    def __init__(self):
        self._data_link = None
        self._data_sync_type = None
        self._file_id = None
        self._request_id = None
        self._sync_timestamp = None

    @property
    def data_link(self):
        return self._data_link

    @data_link.setter
    def data_link(self, value):
        self._data_link = value
    @property
    def data_sync_type(self):
        return self._data_sync_type

    @data_sync_type.setter
    def data_sync_type(self, value):
        self._data_sync_type = value
    @property
    def file_id(self):
        return self._file_id

    @file_id.setter
    def file_id(self, value):
        self._file_id = value
    @property
    def request_id(self):
        return self._request_id

    @request_id.setter
    def request_id(self, value):
        self._request_id = value
    @property
    def sync_timestamp(self):
        return self._sync_timestamp

    @sync_timestamp.setter
    def sync_timestamp(self, value):
        self._sync_timestamp = value


    def to_alipay_dict(self):
        params = dict()
        if self.data_link:
            if hasattr(self.data_link, 'to_alipay_dict'):
                params['data_link'] = self.data_link.to_alipay_dict()
            else:
                params['data_link'] = self.data_link
        if self.data_sync_type:
            if hasattr(self.data_sync_type, 'to_alipay_dict'):
                params['data_sync_type'] = self.data_sync_type.to_alipay_dict()
            else:
                params['data_sync_type'] = self.data_sync_type
        if self.file_id:
            if hasattr(self.file_id, 'to_alipay_dict'):
                params['file_id'] = self.file_id.to_alipay_dict()
            else:
                params['file_id'] = self.file_id
        if self.request_id:
            if hasattr(self.request_id, 'to_alipay_dict'):
                params['request_id'] = self.request_id.to_alipay_dict()
            else:
                params['request_id'] = self.request_id
        if self.sync_timestamp:
            if hasattr(self.sync_timestamp, 'to_alipay_dict'):
                params['sync_timestamp'] = self.sync_timestamp.to_alipay_dict()
            else:
                params['sync_timestamp'] = self.sync_timestamp
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = CommercializationSyncDataReq()
        if 'data_link' in d:
            o.data_link = d['data_link']
        if 'data_sync_type' in d:
            o.data_sync_type = d['data_sync_type']
        if 'file_id' in d:
            o.file_id = d['file_id']
        if 'request_id' in d:
            o.request_id = d['request_id']
        if 'sync_timestamp' in d:
            o.sync_timestamp = d['sync_timestamp']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AccountRecord(object):

    def __init__(self):
        self._alipay_order_no = None
        self._balance = None
        self._business_type = None
        self._create_time = None
        self._in_amount = None
        self._memo = None
        self._merchant_order_no = None
        self._opt_user_id = None
        self._out_amount = None
        self._self_user_id = None
        self._type = None

    @property
    def alipay_order_no(self):
        return self._alipay_order_no

    @alipay_order_no.setter
    def alipay_order_no(self, value):
        self._alipay_order_no = value
    @property
    def balance(self):
        return self._balance

    @balance.setter
    def balance(self, value):
        self._balance = value
    @property
    def business_type(self):
        return self._business_type

    @business_type.setter
    def business_type(self, value):
        self._business_type = value
    @property
    def create_time(self):
        return self._create_time

    @create_time.setter
    def create_time(self, value):
        self._create_time = value
    @property
    def in_amount(self):
        return self._in_amount

    @in_amount.setter
    def in_amount(self, value):
        self._in_amount = value
    @property
    def memo(self):
        return self._memo

    @memo.setter
    def memo(self, value):
        self._memo = value
    @property
    def merchant_order_no(self):
        return self._merchant_order_no

    @merchant_order_no.setter
    def merchant_order_no(self, value):
        self._merchant_order_no = value
    @property
    def opt_user_id(self):
        return self._opt_user_id

    @opt_user_id.setter
    def opt_user_id(self, value):
        self._opt_user_id = value
    @property
    def out_amount(self):
        return self._out_amount

    @out_amount.setter
    def out_amount(self, value):
        self._out_amount = value
    @property
    def self_user_id(self):
        return self._self_user_id

    @self_user_id.setter
    def self_user_id(self, value):
        self._self_user_id = value
    @property
    def type(self):
        return self._type

    @type.setter
    def type(self, value):
        self._type = value


    def to_alipay_dict(self):
        params = dict()
        if self.alipay_order_no:
            if hasattr(self.alipay_order_no, 'to_alipay_dict'):
                params['alipay_order_no'] = self.alipay_order_no.to_alipay_dict()
            else:
                params['alipay_order_no'] = self.alipay_order_no
        if self.balance:
            if hasattr(self.balance, 'to_alipay_dict'):
                params['balance'] = self.balance.to_alipay_dict()
            else:
                params['balance'] = self.balance
        if self.business_type:
            if hasattr(self.business_type, 'to_alipay_dict'):
                params['business_type'] = self.business_type.to_alipay_dict()
            else:
                params['business_type'] = self.business_type
        if self.create_time:
            if hasattr(self.create_time, 'to_alipay_dict'):
                params['create_time'] = self.create_time.to_alipay_dict()
            else:
                params['create_time'] = self.create_time
        if self.in_amount:
            if hasattr(self.in_amount, 'to_alipay_dict'):
                params['in_amount'] = self.in_amount.to_alipay_dict()
            else:
                params['in_amount'] = self.in_amount
        if self.memo:
            if hasattr(self.memo, 'to_alipay_dict'):
                params['memo'] = self.memo.to_alipay_dict()
            else:
                params['memo'] = self.memo
        if self.merchant_order_no:
            if hasattr(self.merchant_order_no, 'to_alipay_dict'):
                params['merchant_order_no'] = self.merchant_order_no.to_alipay_dict()
            else:
                params['merchant_order_no'] = self.merchant_order_no
        if self.opt_user_id:
            if hasattr(self.opt_user_id, 'to_alipay_dict'):
                params['opt_user_id'] = self.opt_user_id.to_alipay_dict()
            else:
                params['opt_user_id'] = self.opt_user_id
        if self.out_amount:
            if hasattr(self.out_amount, 'to_alipay_dict'):
                params['out_amount'] = self.out_amount.to_alipay_dict()
            else:
                params['out_amount'] = self.out_amount
        if self.self_user_id:
            if hasattr(self.self_user_id, 'to_alipay_dict'):
                params['self_user_id'] = self.self_user_id.to_alipay_dict()
            else:
                params['self_user_id'] = self.self_user_id
        if self.type:
            if hasattr(self.type, 'to_alipay_dict'):
                params['type'] = self.type.to_alipay_dict()
            else:
                params['type'] = self.type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AccountRecord()
        if 'alipay_order_no' in d:
            o.alipay_order_no = d['alipay_order_no']
        if 'balance' in d:
            o.balance = d['balance']
        if 'business_type' in d:
            o.business_type = d['business_type']
        if 'create_time' in d:
            o.create_time = d['create_time']
        if 'in_amount' in d:
            o.in_amount = d['in_amount']
        if 'memo' in d:
            o.memo = d['memo']
        if 'merchant_order_no' in d:
            o.merchant_order_no = d['merchant_order_no']
        if 'opt_user_id' in d:
            o.opt_user_id = d['opt_user_id']
        if 'out_amount' in d:
            o.out_amount = d['out_amount']
        if 'self_user_id' in d:
            o.self_user_id = d['self_user_id']
        if 'type' in d:
            o.type = d['type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayEbppInvoiceIssueruleCreateModel(object):

    def __init__(self):
        self._account_id = None
        self._agreement_no = None
        self._effective = None
        self._effective_period = None
        self._enterprise_id = None
        self._invalid_mode = None
        self._invalid_mode_value = None
        self._issue_amount_value = None
        self._issue_end_date = None
        self._issue_rule_name = None
        self._issue_start_date = None
        self._issue_type = None
        self._quota_type = None
        self._share_mode = None
        self._target_id = None
        self._target_type = None

    @property
    def account_id(self):
        return self._account_id

    @account_id.setter
    def account_id(self, value):
        self._account_id = value
    @property
    def agreement_no(self):
        return self._agreement_no

    @agreement_no.setter
    def agreement_no(self, value):
        self._agreement_no = value
    @property
    def effective(self):
        return self._effective

    @effective.setter
    def effective(self, value):
        self._effective = value
    @property
    def effective_period(self):
        return self._effective_period

    @effective_period.setter
    def effective_period(self, value):
        self._effective_period = value
    @property
    def enterprise_id(self):
        return self._enterprise_id

    @enterprise_id.setter
    def enterprise_id(self, value):
        self._enterprise_id = value
    @property
    def invalid_mode(self):
        return self._invalid_mode

    @invalid_mode.setter
    def invalid_mode(self, value):
        self._invalid_mode = value
    @property
    def invalid_mode_value(self):
        return self._invalid_mode_value

    @invalid_mode_value.setter
    def invalid_mode_value(self, value):
        self._invalid_mode_value = value
    @property
    def issue_amount_value(self):
        return self._issue_amount_value

    @issue_amount_value.setter
    def issue_amount_value(self, value):
        self._issue_amount_value = value
    @property
    def issue_end_date(self):
        return self._issue_end_date

    @issue_end_date.setter
    def issue_end_date(self, value):
        self._issue_end_date = value
    @property
    def issue_rule_name(self):
        return self._issue_rule_name

    @issue_rule_name.setter
    def issue_rule_name(self, value):
        self._issue_rule_name = value
    @property
    def issue_start_date(self):
        return self._issue_start_date

    @issue_start_date.setter
    def issue_start_date(self, value):
        self._issue_start_date = value
    @property
    def issue_type(self):
        return self._issue_type

    @issue_type.setter
    def issue_type(self, value):
        self._issue_type = value
    @property
    def quota_type(self):
        return self._quota_type

    @quota_type.setter
    def quota_type(self, value):
        self._quota_type = value
    @property
    def share_mode(self):
        return self._share_mode

    @share_mode.setter
    def share_mode(self, value):
        self._share_mode = value
    @property
    def target_id(self):
        return self._target_id

    @target_id.setter
    def target_id(self, value):
        self._target_id = value
    @property
    def target_type(self):
        return self._target_type

    @target_type.setter
    def target_type(self, value):
        self._target_type = value


    def to_alipay_dict(self):
        params = dict()
        if self.account_id:
            if hasattr(self.account_id, 'to_alipay_dict'):
                params['account_id'] = self.account_id.to_alipay_dict()
            else:
                params['account_id'] = self.account_id
        if self.agreement_no:
            if hasattr(self.agreement_no, 'to_alipay_dict'):
                params['agreement_no'] = self.agreement_no.to_alipay_dict()
            else:
                params['agreement_no'] = self.agreement_no
        if self.effective:
            if hasattr(self.effective, 'to_alipay_dict'):
                params['effective'] = self.effective.to_alipay_dict()
            else:
                params['effective'] = self.effective
        if self.effective_period:
            if hasattr(self.effective_period, 'to_alipay_dict'):
                params['effective_period'] = self.effective_period.to_alipay_dict()
            else:
                params['effective_period'] = self.effective_period
        if self.enterprise_id:
            if hasattr(self.enterprise_id, 'to_alipay_dict'):
                params['enterprise_id'] = self.enterprise_id.to_alipay_dict()
            else:
                params['enterprise_id'] = self.enterprise_id
        if self.invalid_mode:
            if hasattr(self.invalid_mode, 'to_alipay_dict'):
                params['invalid_mode'] = self.invalid_mode.to_alipay_dict()
            else:
                params['invalid_mode'] = self.invalid_mode
        if self.invalid_mode_value:
            if hasattr(self.invalid_mode_value, 'to_alipay_dict'):
                params['invalid_mode_value'] = self.invalid_mode_value.to_alipay_dict()
            else:
                params['invalid_mode_value'] = self.invalid_mode_value
        if self.issue_amount_value:
            if hasattr(self.issue_amount_value, 'to_alipay_dict'):
                params['issue_amount_value'] = self.issue_amount_value.to_alipay_dict()
            else:
                params['issue_amount_value'] = self.issue_amount_value
        if self.issue_end_date:
            if hasattr(self.issue_end_date, 'to_alipay_dict'):
                params['issue_end_date'] = self.issue_end_date.to_alipay_dict()
            else:
                params['issue_end_date'] = self.issue_end_date
        if self.issue_rule_name:
            if hasattr(self.issue_rule_name, 'to_alipay_dict'):
                params['issue_rule_name'] = self.issue_rule_name.to_alipay_dict()
            else:
                params['issue_rule_name'] = self.issue_rule_name
        if self.issue_start_date:
            if hasattr(self.issue_start_date, 'to_alipay_dict'):
                params['issue_start_date'] = self.issue_start_date.to_alipay_dict()
            else:
                params['issue_start_date'] = self.issue_start_date
        if self.issue_type:
            if hasattr(self.issue_type, 'to_alipay_dict'):
                params['issue_type'] = self.issue_type.to_alipay_dict()
            else:
                params['issue_type'] = self.issue_type
        if self.quota_type:
            if hasattr(self.quota_type, 'to_alipay_dict'):
                params['quota_type'] = self.quota_type.to_alipay_dict()
            else:
                params['quota_type'] = self.quota_type
        if self.share_mode:
            if hasattr(self.share_mode, 'to_alipay_dict'):
                params['share_mode'] = self.share_mode.to_alipay_dict()
            else:
                params['share_mode'] = self.share_mode
        if self.target_id:
            if hasattr(self.target_id, 'to_alipay_dict'):
                params['target_id'] = self.target_id.to_alipay_dict()
            else:
                params['target_id'] = self.target_id
        if self.target_type:
            if hasattr(self.target_type, 'to_alipay_dict'):
                params['target_type'] = self.target_type.to_alipay_dict()
            else:
                params['target_type'] = self.target_type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayEbppInvoiceIssueruleCreateModel()
        if 'account_id' in d:
            o.account_id = d['account_id']
        if 'agreement_no' in d:
            o.agreement_no = d['agreement_no']
        if 'effective' in d:
            o.effective = d['effective']
        if 'effective_period' in d:
            o.effective_period = d['effective_period']
        if 'enterprise_id' in d:
            o.enterprise_id = d['enterprise_id']
        if 'invalid_mode' in d:
            o.invalid_mode = d['invalid_mode']
        if 'invalid_mode_value' in d:
            o.invalid_mode_value = d['invalid_mode_value']
        if 'issue_amount_value' in d:
            o.issue_amount_value = d['issue_amount_value']
        if 'issue_end_date' in d:
            o.issue_end_date = d['issue_end_date']
        if 'issue_rule_name' in d:
            o.issue_rule_name = d['issue_rule_name']
        if 'issue_start_date' in d:
            o.issue_start_date = d['issue_start_date']
        if 'issue_type' in d:
            o.issue_type = d['issue_type']
        if 'quota_type' in d:
            o.quota_type = d['quota_type']
        if 'share_mode' in d:
            o.share_mode = d['share_mode']
        if 'target_id' in d:
            o.target_id = d['target_id']
        if 'target_type' in d:
            o.target_type = d['target_type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayOpenAuthIndustryPlatformCreateTokenResponse(AlipayResponse):

    def __init__(self):
        super(AlipayOpenAuthIndustryPlatformCreateTokenResponse, self).__init__()
        self._auth_code = None
        self._requst_app_id = None
        self._scope = None

    @property
    def auth_code(self):
        return self._auth_code

    @auth_code.setter
    def auth_code(self, value):
        self._auth_code = value
    @property
    def requst_app_id(self):
        return self._requst_app_id

    @requst_app_id.setter
    def requst_app_id(self, value):
        self._requst_app_id = value
    @property
    def scope(self):
        return self._scope

    @scope.setter
    def scope(self, value):
        self._scope = value

    def parse_response_content(self, response_content):
        response = super(AlipayOpenAuthIndustryPlatformCreateTokenResponse, self).parse_response_content(response_content)
        if 'auth_code' in response:
            self.auth_code = response['auth_code']
        if 'requst_app_id' in response:
            self.requst_app_id = response['requst_app_id']
        if 'scope' in response:
            self.scope = response['scope']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.VoucherTemplateInfo import VoucherTemplateInfo


class MarketActivityInfo(object):

    def __init__(self):
        self._activity_id = None
        self._activity_name = None
        self._brand_logo = None
        self._brand_name = None
        self._publish_end_time = None
        self._publish_start_time = None
        self._status = None
        self._voucher_infos = None

    @property
    def activity_id(self):
        return self._activity_id

    @activity_id.setter
    def activity_id(self, value):
        self._activity_id = value
    @property
    def activity_name(self):
        return self._activity_name

    @activity_name.setter
    def activity_name(self, value):
        self._activity_name = value
    @property
    def brand_logo(self):
        return self._brand_logo

    @brand_logo.setter
    def brand_logo(self, value):
        self._brand_logo = value
    @property
    def brand_name(self):
        return self._brand_name

    @brand_name.setter
    def brand_name(self, value):
        self._brand_name = value
    @property
    def publish_end_time(self):
        return self._publish_end_time

    @publish_end_time.setter
    def publish_end_time(self, value):
        self._publish_end_time = value
    @property
    def publish_start_time(self):
        return self._publish_start_time

    @publish_start_time.setter
    def publish_start_time(self, value):
        self._publish_start_time = value
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value
    @property
    def voucher_infos(self):
        return self._voucher_infos

    @voucher_infos.setter
    def voucher_infos(self, value):
        if isinstance(value, list):
            self._voucher_infos = list()
            for i in value:
                if isinstance(i, VoucherTemplateInfo):
                    self._voucher_infos.append(i)
                else:
                    self._voucher_infos.append(VoucherTemplateInfo.from_alipay_dict(i))


    def to_alipay_dict(self):
        params = dict()
        if self.activity_id:
            if hasattr(self.activity_id, 'to_alipay_dict'):
                params['activity_id'] = self.activity_id.to_alipay_dict()
            else:
                params['activity_id'] = self.activity_id
        if self.activity_name:
            if hasattr(self.activity_name, 'to_alipay_dict'):
                params['activity_name'] = self.activity_name.to_alipay_dict()
            else:
                params['activity_name'] = self.activity_name
        if self.brand_logo:
            if hasattr(self.brand_logo, 'to_alipay_dict'):
                params['brand_logo'] = self.brand_logo.to_alipay_dict()
            else:
                params['brand_logo'] = self.brand_logo
        if self.brand_name:
            if hasattr(self.brand_name, 'to_alipay_dict'):
                params['brand_name'] = self.brand_name.to_alipay_dict()
            else:
                params['brand_name'] = self.brand_name
        if self.publish_end_time:
            if hasattr(self.publish_end_time, 'to_alipay_dict'):
                params['publish_end_time'] = self.publish_end_time.to_alipay_dict()
            else:
                params['publish_end_time'] = self.publish_end_time
        if self.publish_start_time:
            if hasattr(self.publish_start_time, 'to_alipay_dict'):
                params['publish_start_time'] = self.publish_start_time.to_alipay_dict()
            else:
                params['publish_start_time'] = self.publish_start_time
        if self.status:
            if hasattr(self.status, 'to_alipay_dict'):
                params['status'] = self.status.to_alipay_dict()
            else:
                params['status'] = self.status
        if self.voucher_infos:
            if isinstance(self.voucher_infos, list):
                for i in range(0, len(self.voucher_infos)):
                    element = self.voucher_infos[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.voucher_infos[i] = element.to_alipay_dict()
            if hasattr(self.voucher_infos, 'to_alipay_dict'):
                params['voucher_infos'] = self.voucher_infos.to_alipay_dict()
            else:
                params['voucher_infos'] = self.voucher_infos
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = MarketActivityInfo()
        if 'activity_id' in d:
            o.activity_id = d['activity_id']
        if 'activity_name' in d:
            o.activity_name = d['activity_name']
        if 'brand_logo' in d:
            o.brand_logo = d['brand_logo']
        if 'brand_name' in d:
            o.brand_name = d['brand_name']
        if 'publish_end_time' in d:
            o.publish_end_time = d['publish_end_time']
        if 'publish_start_time' in d:
            o.publish_start_time = d['publish_start_time']
        if 'status' in d:
            o.status = d['status']
        if 'voucher_infos' in d:
            o.voucher_infos = d['voucher_infos']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class ExtCardInfo(object):

    def __init__(self):
        self._bank_acc_name = None
        self._card_bank = None
        self._card_branch = None
        self._card_deposit = None
        self._card_location = None
        self._card_no = None
        self._status = None

    @property
    def bank_acc_name(self):
        return self._bank_acc_name

    @bank_acc_name.setter
    def bank_acc_name(self, value):
        self._bank_acc_name = value
    @property
    def card_bank(self):
        return self._card_bank

    @card_bank.setter
    def card_bank(self, value):
        self._card_bank = value
    @property
    def card_branch(self):
        return self._card_branch

    @card_branch.setter
    def card_branch(self, value):
        self._card_branch = value
    @property
    def card_deposit(self):
        return self._card_deposit

    @card_deposit.setter
    def card_deposit(self, value):
        self._card_deposit = value
    @property
    def card_location(self):
        return self._card_location

    @card_location.setter
    def card_location(self, value):
        self._card_location = value
    @property
    def card_no(self):
        return self._card_no

    @card_no.setter
    def card_no(self, value):
        self._card_no = value
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value


    def to_alipay_dict(self):
        params = dict()
        if self.bank_acc_name:
            if hasattr(self.bank_acc_name, 'to_alipay_dict'):
                params['bank_acc_name'] = self.bank_acc_name.to_alipay_dict()
            else:
                params['bank_acc_name'] = self.bank_acc_name
        if self.card_bank:
            if hasattr(self.card_bank, 'to_alipay_dict'):
                params['card_bank'] = self.card_bank.to_alipay_dict()
            else:
                params['card_bank'] = self.card_bank
        if self.card_branch:
            if hasattr(self.card_branch, 'to_alipay_dict'):
                params['card_branch'] = self.card_branch.to_alipay_dict()
            else:
                params['card_branch'] = self.card_branch
        if self.card_deposit:
            if hasattr(self.card_deposit, 'to_alipay_dict'):
                params['card_deposit'] = self.card_deposit.to_alipay_dict()
            else:
                params['card_deposit'] = self.card_deposit
        if self.card_location:
            if hasattr(self.card_location, 'to_alipay_dict'):
                params['card_location'] = self.card_location.to_alipay_dict()
            else:
                params['card_location'] = self.card_location
        if self.card_no:
            if hasattr(self.card_no, 'to_alipay_dict'):
                params['card_no'] = self.card_no.to_alipay_dict()
            else:
                params['card_no'] = self.card_no
        if self.status:
            if hasattr(self.status, 'to_alipay_dict'):
                params['status'] = self.status.to_alipay_dict()
            else:
                params['status'] = self.status
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = ExtCardInfo()
        if 'bank_acc_name' in d:
            o.bank_acc_name = d['bank_acc_name']
        if 'card_bank' in d:
            o.card_bank = d['card_bank']
        if 'card_branch' in d:
            o.card_branch = d['card_branch']
        if 'card_deposit' in d:
            o.card_deposit = d['card_deposit']
        if 'card_location' in d:
            o.card_location = d['card_location']
        if 'card_no' in d:
            o.card_no = d['card_no']
        if 'status' in d:
            o.status = d['status']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.MaintainOrderStatusExtParams import MaintainOrderStatusExtParams


class AlipayEcoMycarMaintainOrderstatusUpdateModel(object):

    def __init__(self):
        self._ext_param = None
        self._industry_code = None
        self._order_no = None
        self._order_status = None
        self._type = None

    @property
    def ext_param(self):
        return self._ext_param

    @ext_param.setter
    def ext_param(self, value):
        if isinstance(value, MaintainOrderStatusExtParams):
            self._ext_param = value
        else:
            self._ext_param = MaintainOrderStatusExtParams.from_alipay_dict(value)
    @property
    def industry_code(self):
        return self._industry_code

    @industry_code.setter
    def industry_code(self, value):
        self._industry_code = value
    @property
    def order_no(self):
        return self._order_no

    @order_no.setter
    def order_no(self, value):
        self._order_no = value
    @property
    def order_status(self):
        return self._order_status

    @order_status.setter
    def order_status(self, value):
        self._order_status = value
    @property
    def type(self):
        return self._type

    @type.setter
    def type(self, value):
        self._type = value


    def to_alipay_dict(self):
        params = dict()
        if self.ext_param:
            if hasattr(self.ext_param, 'to_alipay_dict'):
                params['ext_param'] = self.ext_param.to_alipay_dict()
            else:
                params['ext_param'] = self.ext_param
        if self.industry_code:
            if hasattr(self.industry_code, 'to_alipay_dict'):
                params['industry_code'] = self.industry_code.to_alipay_dict()
            else:
                params['industry_code'] = self.industry_code
        if self.order_no:
            if hasattr(self.order_no, 'to_alipay_dict'):
                params['order_no'] = self.order_no.to_alipay_dict()
            else:
                params['order_no'] = self.order_no
        if self.order_status:
            if hasattr(self.order_status, 'to_alipay_dict'):
                params['order_status'] = self.order_status.to_alipay_dict()
            else:
                params['order_status'] = self.order_status
        if self.type:
            if hasattr(self.type, 'to_alipay_dict'):
                params['type'] = self.type.to_alipay_dict()
            else:
                params['type'] = self.type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayEcoMycarMaintainOrderstatusUpdateModel()
        if 'ext_param' in d:
            o.ext_param = d['ext_param']
        if 'industry_code' in d:
            o.industry_code = d['industry_code']
        if 'order_no' in d:
            o.order_no = d['order_no']
        if 'order_status' in d:
            o.order_status = d['order_status']
        if 'type' in d:
            o.type = d['type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayTradeBatchTransferResponse(AlipayResponse):

    def __init__(self):
        super(AlipayTradeBatchTransferResponse, self).__init__()
        self._gmt_create = None
        self._out_request_no = None
        self._result_code = None
        self._settle_no = None

    @property
    def gmt_create(self):
        return self._gmt_create

    @gmt_create.setter
    def gmt_create(self, value):
        self._gmt_create = value
    @property
    def out_request_no(self):
        return self._out_request_no

    @out_request_no.setter
    def out_request_no(self, value):
        self._out_request_no = value
    @property
    def result_code(self):
        return self._result_code

    @result_code.setter
    def result_code(self, value):
        self._result_code = value
    @property
    def settle_no(self):
        return self._settle_no

    @settle_no.setter
    def settle_no(self, value):
        self._settle_no = value

    def parse_response_content(self, response_content):
        response = super(AlipayTradeBatchTransferResponse, self).parse_response_content(response_content)
        if 'gmt_create' in response:
            self.gmt_create = response['gmt_create']
        if 'out_request_no' in response:
            self.out_request_no = response['out_request_no']
        if 'result_code' in response:
            self.result_code = response['result_code']
        if 'settle_no' in response:
            self.settle_no = response['settle_no']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class MybankCreditLoantradeGuarletterCompensateApplyModel(object):

    def __init__(self):
        self._apply_user_cert_no = None
        self._apply_user_name = None
        self._apply_user_phone = None
        self._beneficiary_bank_card_no = None
        self._beneficiary_bank_name = None
        self._file_list = None
        self._guar_letter_order_no = None
        self._reason = None
        self._request_id = None
        self._scheme_ar_no = None

    @property
    def apply_user_cert_no(self):
        return self._apply_user_cert_no

    @apply_user_cert_no.setter
    def apply_user_cert_no(self, value):
        self._apply_user_cert_no = value
    @property
    def apply_user_name(self):
        return self._apply_user_name

    @apply_user_name.setter
    def apply_user_name(self, value):
        self._apply_user_name = value
    @property
    def apply_user_phone(self):
        return self._apply_user_phone

    @apply_user_phone.setter
    def apply_user_phone(self, value):
        self._apply_user_phone = value
    @property
    def beneficiary_bank_card_no(self):
        return self._beneficiary_bank_card_no

    @beneficiary_bank_card_no.setter
    def beneficiary_bank_card_no(self, value):
        self._beneficiary_bank_card_no = value
    @property
    def beneficiary_bank_name(self):
        return self._beneficiary_bank_name

    @beneficiary_bank_name.setter
    def beneficiary_bank_name(self, value):
        self._beneficiary_bank_name = value
    @property
    def file_list(self):
        return self._file_list

    @file_list.setter
    def file_list(self, value):
        self._file_list = value
    @property
    def guar_letter_order_no(self):
        return self._guar_letter_order_no

    @guar_letter_order_no.setter
    def guar_letter_order_no(self, value):
        self._guar_letter_order_no = value
    @property
    def reason(self):
        return self._reason

    @reason.setter
    def reason(self, value):
        self._reason = value
    @property
    def request_id(self):
        return self._request_id

    @request_id.setter
    def request_id(self, value):
        self._request_id = value
    @property
    def scheme_ar_no(self):
        return self._scheme_ar_no

    @scheme_ar_no.setter
    def scheme_ar_no(self, value):
        self._scheme_ar_no = value


    def to_alipay_dict(self):
        params = dict()
        if self.apply_user_cert_no:
            if hasattr(self.apply_user_cert_no, 'to_alipay_dict'):
                params['apply_user_cert_no'] = self.apply_user_cert_no.to_alipay_dict()
            else:
                params['apply_user_cert_no'] = self.apply_user_cert_no
        if self.apply_user_name:
            if hasattr(self.apply_user_name, 'to_alipay_dict'):
                params['apply_user_name'] = self.apply_user_name.to_alipay_dict()
            else:
                params['apply_user_name'] = self.apply_user_name
        if self.apply_user_phone:
            if hasattr(self.apply_user_phone, 'to_alipay_dict'):
                params['apply_user_phone'] = self.apply_user_phone.to_alipay_dict()
            else:
                params['apply_user_phone'] = self.apply_user_phone
        if self.beneficiary_bank_card_no:
            if hasattr(self.beneficiary_bank_card_no, 'to_alipay_dict'):
                params['beneficiary_bank_card_no'] = self.beneficiary_bank_card_no.to_alipay_dict()
            else:
                params['beneficiary_bank_card_no'] = self.beneficiary_bank_card_no
        if self.beneficiary_bank_name:
            if hasattr(self.beneficiary_bank_name, 'to_alipay_dict'):
                params['beneficiary_bank_name'] = self.beneficiary_bank_name.to_alipay_dict()
            else:
                params['beneficiary_bank_name'] = self.beneficiary_bank_name
        if self.file_list:
            if hasattr(self.file_list, 'to_alipay_dict'):
                params['file_list'] = self.file_list.to_alipay_dict()
            else:
                params['file_list'] = self.file_list
        if self.guar_letter_order_no:
            if hasattr(self.guar_letter_order_no, 'to_alipay_dict'):
                params['guar_letter_order_no'] = self.guar_letter_order_no.to_alipay_dict()
            else:
                params['guar_letter_order_no'] = self.guar_letter_order_no
        if self.reason:
            if hasattr(self.reason, 'to_alipay_dict'):
                params['reason'] = self.reason.to_alipay_dict()
            else:
                params['reason'] = self.reason
        if self.request_id:
            if hasattr(self.request_id, 'to_alipay_dict'):
                params['request_id'] = self.request_id.to_alipay_dict()
            else:
                params['request_id'] = self.request_id
        if self.scheme_ar_no:
            if hasattr(self.scheme_ar_no, 'to_alipay_dict'):
                params['scheme_ar_no'] = self.scheme_ar_no.to_alipay_dict()
            else:
                params['scheme_ar_no'] = self.scheme_ar_no
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = MybankCreditLoantradeGuarletterCompensateApplyModel()
        if 'apply_user_cert_no' in d:
            o.apply_user_cert_no = d['apply_user_cert_no']
        if 'apply_user_name' in d:
            o.apply_user_name = d['apply_user_name']
        if 'apply_user_phone' in d:
            o.apply_user_phone = d['apply_user_phone']
        if 'beneficiary_bank_card_no' in d:
            o.beneficiary_bank_card_no = d['beneficiary_bank_card_no']
        if 'beneficiary_bank_name' in d:
            o.beneficiary_bank_name = d['beneficiary_bank_name']
        if 'file_list' in d:
            o.file_list = d['file_list']
        if 'guar_letter_order_no' in d:
            o.guar_letter_order_no = d['guar_letter_order_no']
        if 'reason' in d:
            o.reason = d['reason']
        if 'request_id' in d:
            o.request_id = d['request_id']
        if 'scheme_ar_no' in d:
            o.scheme_ar_no = d['scheme_ar_no']
        return o


